/*******************************************************************************
 *
 * MIT License
 *
 * Copyright (c) 2021 Advanced Micro Devices, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 *******************************************************************************/

#pragma once

#include <miopen/invoke_params.hpp>
#include <miopen/pooling.hpp>
#include <miopen/tensor.hpp>

namespace miopen {
namespace pooling {

struct FwdInvokeParams : public miopen::InvokeParams
{
    FwdInvokeParams() = default;

    TensorDescriptor xDesc;
    TensorDescriptor yDesc;
    PoolingDescriptor pooling;

    ConstData_t x              = nullptr;
    Data_t y                   = nullptr;
    Data_t workspace           = nullptr;
    std::size_t workspace_size = 0;

    std::size_t GetWorkspaceSize() const { return workspace_size; }
    Data_t GetWorkspace() const { return workspace; }
};

struct BwdInvokeParams : public miopen::InvokeParams
{
    BwdInvokeParams() = default;

    TensorDescriptor dxDesc;
    TensorDescriptor dyDesc;
    PoolingDescriptor pooling;

    Data_t dx        = nullptr;
    ConstData_t dy   = nullptr;
    Data_t workspace = nullptr;
    // For some reason, pooling API doesn't have a paramter for this. So in reality it is always
    // zero.
    std::size_t workspace_size = 0;

    std::size_t GetWorkspaceSize() const { return workspace_size; }
    Data_t GetWorkspace() const { return workspace; }
};

} // namespace pooling

} // namespace miopen
