/*******************************************************************************
 *
 * MIT License
 *
 * Copyright (c) 2021 Advanced Micro Devices, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 *******************************************************************************/
#include <algorithm>
#include <unordered_map>
#include <string_view>
#include <miopen/filesystem.hpp>
#include <miopen/kernel.hpp>

#ifndef MIOPEN_USE_CLANG_TIDY // Huge generated source
// clang-format off
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_NCDHW_KCZYX_NKDHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_NCDHW_KCZYX_NKDHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_XDLOPS_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_XDLOPS_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_NCDHW_KCZYX_NKDHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_NCDHW_KCZYX_NKDHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_XDLOPS_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_XDLOPS_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_NCDHW_KCZYX_NKDHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_NCDHW_KCZYX_NKDHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_PADDED_GEMM_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_PADDED_GEMM[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_PADDED_GEMM_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_PADDED_GEMM[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R5_XDLOPS_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R5_XDLOPS_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R1_GNCHW_GKCYX_GNKHW_LDS_DOUBLE_BUFFER_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R1_GNCHW_GKCYX_GNKHW_LDS_DOUBLE_BUFFER[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R1_NCHW_KCYX_NKHW_LDS_DOUBLE_BUFFER_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R1_NCHW_KCYX_NKHW_LDS_DOUBLE_BUFFER[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R4_NCDHW_KCZYX_NKDHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R4_NCDHW_KCZYX_NKDHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R4_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R4_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL[];
extern const size_t MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_SIZE;
extern const char MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL[];
extern const size_t MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_DLOPS_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_DLOPS_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NHWC_KYXC_NHWK_SIZE;
extern const char MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NHWC_KYXC_NHWK[];
extern const size_t MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V6R1_DLOPS_NCHW_KCYX_NKHW_SIZE;
extern const char MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V6R1_DLOPS_NCHW_KCYX_NKHW[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_BLOCKWISE_REDUCE_ALL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_BLOCKWISE_REDUCE_ALL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_BLOCKWISE_REDUCE_PARTIAL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_BLOCKWISE_REDUCE_PARTIAL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_MULTIBLOCK_REDUCE_ALL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_MULTIBLOCK_REDUCE_ALL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_MULTIBLOCK_REDUCE_PARTIAL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_MULTIBLOCK_REDUCE_PARTIAL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_THREADWISE_REDUCE_ALL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_THREADWISE_REDUCE_ALL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_THREADWISE_REDUCE_PARTIAL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_THREADWISE_REDUCE_PARTIAL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_WARPWISE_REDUCE_ALL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_WARPWISE_REDUCE_ALL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_WARPWISE_REDUCE_PARTIAL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_WARPWISE_REDUCE_PARTIAL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_BLOCKWISE_REDUCE_ALL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_BLOCKWISE_REDUCE_ALL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_BLOCKWISE_REDUCE_PARTIAL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_BLOCKWISE_REDUCE_PARTIAL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_THREADWISE_REDUCE_ALL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_THREADWISE_REDUCE_ALL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_THREADWISE_REDUCE_PARTIAL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_THREADWISE_REDUCE_PARTIAL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_WARPWISE_REDUCE_ALL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_WARPWISE_REDUCE_ALL_DIMS[];
extern const size_t MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_WARPWISE_REDUCE_PARTIAL_DIMS_SIZE;
extern const char MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_WARPWISE_REDUCE_PARTIAL_DIMS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTC_DYNAMIC_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTC_DYNAMIC[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X1X2X4_1X16X1X16_TB1X1X4X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X1X2X4_1X16X1X16_TB1X1X4X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X2X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X2X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X1X2X4_1X16X1X16_TB1X1X4X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X1X2X4_1X16X1X16_TB1X1X4X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X2X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X2X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X4_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X4_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX8_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX8_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX8_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX8_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X2_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X2_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X2_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X2_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X8_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X8_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X2_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X2_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X2_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X2_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X2_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X2_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X2_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X2_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X1X2_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X1X2_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X1X4_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X1X4_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X8X1X1_1X8X1X32_TB1X8X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X8X1X1_1X8X1X32_TB1X8X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X8_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA2X1X8X1_1X8X1X16_TB2X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA2X1X8X1_1X8X1X16_TB2X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X16_TB2X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X16_TB2X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X1X8X1_1X16X1X4_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X1X8X1_1X16X1X4_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA2X1X4X1_1X8X1X8_TB2X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA2X1X4X1_1X8X1X8_TB2X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA4X1X2X1_1X4X1X16_TB4X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA4X1X2X1_1X4X1X16_TB4X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X8X1X8_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X4X1X16_TB2X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X4X1X16_TB2X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X4X1_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X4X1_1X32X1X8_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA2X1X2X1_1X16X1X16_TB2X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA2X1X2X1_1X16X1X16_TB2X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA4X1X1X1_1X8X1X32_TB4X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA4X1X1X1_1X8X1X32_TB4X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X1X8X1_1X64X1X4_TB1X1X8X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X1X8X1_1X64X1X4_TB1X1X8X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA2X1X4X1_1X32X1X8_TB2X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA2X1X4X1_1X32X1X8_TB2X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA4X1X2X1_1X16X1X16_TB4X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA4X1X2X1_1X16X1X16_TB4X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA8X1X1X1_1X8X1X32_TB8X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA8X1X1X1_1X8X1X32_TB8X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X1X8X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X1X8X1_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA2X1X4X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA2X1X4X1_1X16X1X16_TB2X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA4X1X2X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA4X1X2X1_1X8X1X32_TB4X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA8X1X1X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA8X1X1X1_1X4X1X64_TB8X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X16X1X16_TB1X2X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X2_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X2_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X2_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X2_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X8_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X8_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X2_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X2_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X2_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X2_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X2_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X2_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X2_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X2_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X1X2_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X1X2_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X1X4_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X1X4_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X8X1X1_1X8X1X32_TB1X8X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X8X1X1_1X8X1X32_TB1X8X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X8_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA2X1X8X1_1X8X1X16_TB2X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA2X1X8X1_1X8X1X16_TB2X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X16_TB2X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X16_TB2X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X1X8X1_1X16X1X4_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X1X8X1_1X16X1X4_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA2X1X4X1_1X8X1X8_TB2X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA2X1X4X1_1X8X1X8_TB2X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA4X1X2X1_1X4X1X16_TB4X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA4X1X2X1_1X4X1X16_TB4X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X8X1X8_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X4X1X16_TB2X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X4X1X16_TB2X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X4X1_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X4X1_1X32X1X8_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA2X1X2X1_1X16X1X16_TB2X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA2X1X2X1_1X16X1X16_TB2X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA4X1X1X1_1X8X1X32_TB4X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA4X1X1X1_1X8X1X32_TB4X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X1X8X1_1X64X1X4_TB1X1X8X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X1X8X1_1X64X1X4_TB1X1X8X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA2X1X4X1_1X32X1X8_TB2X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA2X1X4X1_1X32X1X8_TB2X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA4X1X2X1_1X16X1X16_TB4X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA4X1X2X1_1X16X1X16_TB4X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA8X1X1X1_1X8X1X32_TB8X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA8X1X1X1_1X8X1X32_TB8X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X1X8X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X1X8X1_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA2X1X4X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA2X1X4X1_1X16X1X16_TB2X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA4X1X2X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA4X1X2X1_1X8X1X32_TB4X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA8X1X1X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA8X1X1X1_1X4X1X64_TB8X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X16X1X16_TB1X2X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX16_EX0_BT16X16X4_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX16_EX0_BT16X16X4_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX16_EX1_BT16X16X4_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX16_EX1_BT16X16X4_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X32_WT32X8X1_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X32_WT32X8X1_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X32_WT8X32X1_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X32_WT8X32X1_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X32_WT8X32X1_WS2X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X32_WT8X32X1_WS2X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X64_WT16X16X1_WS1X1_WR2X2_TA1X4X1X4_1X16X1X16_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X64_WT16X16X1_WS1X1_WR2X2_TA1X4X1X4_1X16X1X16_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X32_WT32X8X1_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X32_WT32X8X1_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX32_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X8X2X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX32_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X8X2X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX64_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX64_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX64_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX64_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX8_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX8_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X1X16_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X1X16_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X2X1X8_1X16X1X16_TB1X2X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X2X1X8_1X16X1X16_TB1X2X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X2X1X8_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X2X1X8_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X2X1X1_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X2X1X1_1X16X1X16_TB1X2X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X2X1X1_1X16X1X16_TB1X2X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X2X1X1_1X16X1X16_TB1X2X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X2X1X16_1X16X1X16_TB1X2X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X2X1X16_1X16X1X16_TB1X2X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X2X1X16_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X2X1X16_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X4_TB1X2X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X4_TB1X2X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X4_TB1X2X16X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X4_TB1X2X16X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X16_1X16X1X4_TB1X2X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X16_1X16X1X4_TB1X2X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X16_1X16X1X4_TB1X2X1X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X16_1X16X1X4_TB1X2X1X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X1X1X16_1X32X1X8_TB1X1X2X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X1X1X16_1X32X1X8_TB1X1X2X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X1X1X16_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X1X1X16_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X1X1X2_1X32X1X8_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X1X1X2_1X32X1X8_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X1X1X2_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X1X1X2_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X2X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X2X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X2_TB1X1X32X1_1X32X1X2_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X2_TB1X1X32X1_1X32X1X2[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X2_TB1X1X32X1_1X32X1X2_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X2_TB1X1X32X1_1X32X1X2_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X16X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X2X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X2X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X32X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X32X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X4X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X32_1X32X1X2_TB1X1X2X1_1X32X1X2_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X32_1X32X1X2_TB1X1X2X1_1X32X1X2[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X32_1X32X1X2_TB1X1X2X1_1X32X1X2_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X32_1X32X1X2_TB1X1X2X1_1X32X1X2_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X8X1_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X1X2_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X1X2_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_V4R1_DYNAMIC_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_V4R1_DYNAMIC[];
extern const size_t MIOPEN_KERNEL_IGEMM_V4R1_WRW_DYNAMIC_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_V4R1_WRW_DYNAMIC[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X16X8_WT32X8X1_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X16X8_WT32X8X1_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X16X8_WT32X8X1_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X16X8_WT32X8X1_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_GKGS[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32[];
extern const size_t MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE;
extern const char MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS[];
extern const size_t MIOPEN_KERNEL_WRW_REDUCTION_HIP_SIZE;
extern const char MIOPEN_KERNEL_WRW_REDUCTION_HIP[];
extern const size_t MIOPEN_KERNEL_FP8_NAIVE_CONV_SIZE;
extern const char MIOPEN_KERNEL_FP8_NAIVE_CONV[];
extern const size_t MIOPEN_KERNEL_NAIVE_CONV_SIZE;
extern const char MIOPEN_KERNEL_NAIVE_CONV[];
extern const size_t MIOPEN_KERNEL_NAIVE_CONV_GCN_SIZE;
extern const char MIOPEN_KERNEL_NAIVE_CONV_GCN[];
extern const size_t MIOPEN_KERNEL_BATCHED_TRANSPOSE_SIZE;
extern const char MIOPEN_KERNEL_BATCHED_TRANSPOSE[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_BYTE_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_BYTE[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_DWORD_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_DWORD[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_DWORDX2_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_DWORDX2[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_HALF_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_HALF[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_BYTE_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_BYTE[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_DWORD_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_DWORD[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_DWORDX2_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_DWORDX2[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_HALF_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_HALF[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_BYTE_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_BYTE[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_DWORD_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_DWORD[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_DWORDX2_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_DWORDX2[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_HALF_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_HALF[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_BYTE_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_BYTE[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_DWORD_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_DWORD[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_DWORDX2_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_DWORDX2[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_HALF_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_HALF[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_BYTE_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_BYTE[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_DWORD_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_DWORD[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_DWORDX2_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_DWORDX2[];
extern const size_t MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_HALF_SIZE;
extern const char MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_HALF[];
extern const size_t MIOPEN_KERNEL_MIOPENADAM_SIZE;
extern const char MIOPEN_KERNEL_MIOPENADAM[];
extern const size_t MIOPEN_KERNEL_MIOPENCAT_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCAT[];
extern const size_t MIOPEN_KERNEL_MIOPENCHECKNUMERICS_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCHECKNUMERICS[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMACTIVBWDPERACT_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMACTIVBWDPERACT[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMACTIVBWDSPATIAL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMACTIVBWDSPATIAL[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMACTIVFWDTRAINPERACT_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMACTIVFWDTRAINPERACT[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMACTIVFWDTRAINSPATIAL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMACTIVFWDTRAINSPATIAL[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMFWDTRAINSPATIAL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMFWDTRAINSPATIAL[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMFWDTRAINPERACT_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMFWDTRAINPERACT[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMFWDINFERSPATIAL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMFWDINFERSPATIAL[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMFWDINFERPERACT_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMFWDINFERPERACT[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMBWDSPATIAL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMBWDSPATIAL[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMBWDPERACT_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMBWDPERACT[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVDIRUNI_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVDIRUNI[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVDIRBATCHNORMACTIV_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVDIRBATCHNORMACTIV[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVDIRGENFWD_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVDIRGENFWD[];
extern const size_t MIOPEN_KERNEL_MIOPENGLU_SIZE;
extern const char MIOPEN_KERNEL_MIOPENGLU[];
extern const size_t MIOPEN_KERNEL_MIOPENGROUPNORM_SIZE;
extern const char MIOPEN_KERNEL_MIOPENGROUPNORM[];
extern const size_t MIOPEN_KERNEL_MIOPENGETITEM_SIZE;
extern const char MIOPEN_KERNEL_MIOPENGETITEM[];
extern const size_t MIOPEN_KERNEL_MIOPENKTHVALUE_SIZE;
extern const char MIOPEN_KERNEL_MIOPENKTHVALUE[];
extern const size_t MIOPEN_KERNEL_MIOPENLAYERNORM_SIZE;
extern const char MIOPEN_KERNEL_MIOPENLAYERNORM[];
extern const size_t MIOPEN_KERNEL_MIOPENLRNBWD_SIZE;
extern const char MIOPEN_KERNEL_MIOPENLRNBWD[];
extern const size_t MIOPEN_KERNEL_MIOPENLRNFWD_SIZE;
extern const char MIOPEN_KERNEL_MIOPENLRNFWD[];
extern const size_t MIOPEN_KERNEL_MIOPENMULTIMARGINLOSS_SIZE;
extern const char MIOPEN_KERNEL_MIOPENMULTIMARGINLOSS[];
extern const size_t MIOPEN_KERNEL_MIOPENNEURON_SIZE;
extern const char MIOPEN_KERNEL_MIOPENNEURON[];
extern const size_t MIOPEN_KERNEL_MIOPENPRELU_SIZE;
extern const char MIOPEN_KERNEL_MIOPENPRELU[];
extern const size_t MIOPEN_KERNEL_MIOPENPOOLING_SIZE;
extern const char MIOPEN_KERNEL_MIOPENPOOLING[];
extern const size_t MIOPEN_KERNEL_MIOPENPOOLINGBWD_SIZE;
extern const char MIOPEN_KERNEL_MIOPENPOOLINGBWD[];
extern const size_t MIOPEN_KERNEL_MIOPENPOOLINGBWDND_SIZE;
extern const char MIOPEN_KERNEL_MIOPENPOOLINGBWDND[];
extern const size_t MIOPEN_KERNEL_MIOPENPOOLINGFORWARDNAIVE_SIZE;
extern const char MIOPEN_KERNEL_MIOPENPOOLINGFORWARDNAIVE[];
extern const size_t MIOPEN_KERNEL_MIOPENPOOLINGND_SIZE;
extern const char MIOPEN_KERNEL_MIOPENPOOLINGND[];
extern const size_t MIOPEN_KERNEL_MIOPENCONV1X1S_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONV1X1S[];
extern const size_t MIOPEN_KERNEL_MIOPENCONV1X1J1_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONV1X1J1[];
extern const size_t MIOPEN_KERNEL_MIOPENCONV1X1J1_STRIDE_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONV1X1J1_STRIDE[];
extern const size_t MIOPEN_KERNEL_MIOPENREDUCECALCULATION_SIZE;
extern const char MIOPEN_KERNEL_MIOPENREDUCECALCULATION[];
extern const size_t MIOPEN_KERNEL_MIOPENREDUCEEXTREME_SIZE;
extern const char MIOPEN_KERNEL_MIOPENREDUCEEXTREME[];
extern const size_t MIOPEN_KERNEL_MIOPENREDUCESUM_SIZE;
extern const char MIOPEN_KERNEL_MIOPENREDUCESUM[];
extern const size_t MIOPEN_KERNEL_MIOPENROPE_SIZE;
extern const char MIOPEN_KERNEL_MIOPENROPE[];
extern const size_t MIOPEN_KERNEL_MIOPENSOFTMARGINLOSS_SIZE;
extern const char MIOPEN_KERNEL_MIOPENSOFTMARGINLOSS[];
extern const size_t MIOPEN_KERNEL_MIOPENSOFTMAX_SIZE;
extern const char MIOPEN_KERNEL_MIOPENSOFTMAX[];
extern const size_t MIOPEN_KERNEL_MIOPENSOFTMAXATTN_SIZE;
extern const char MIOPEN_KERNEL_MIOPENSOFTMAXATTN[];
extern const size_t MIOPEN_KERNEL_MIOPENUTILKERNELS3_SIZE;
extern const char MIOPEN_KERNEL_MIOPENUTILKERNELS3[];
extern const size_t MIOPEN_KERNEL_MIOPENUTILKERNELS4_SIZE;
extern const char MIOPEN_KERNEL_MIOPENUTILKERNELS4[];
extern const size_t MIOPEN_KERNEL_MIOPENUTILKERNELS5_SIZE;
extern const char MIOPEN_KERNEL_MIOPENUTILKERNELS5[];
extern const size_t MIOPEN_KERNEL_MIOPENVECADD_SIZE;
extern const char MIOPEN_KERNEL_MIOPENVECADD[];
extern const size_t MIOPEN_KERNEL_MIOPENVECADDOCL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENVECADDOCL[];
extern const size_t MIOPEN_KERNEL_MIOPENIM2D2COL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENIM2D2COL[];
extern const size_t MIOPEN_KERNEL_MIOPENIM3D2COL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENIM3D2COL[];
extern const size_t MIOPEN_KERNEL_MIOPENCOL2IM2D_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCOL2IM2D[];
extern const size_t MIOPEN_KERNEL_MIOPENCOL2IM3D_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCOL2IM3D[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVBWDWRWS2_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVBWDWRWS2[];
extern const size_t MIOPEN_KERNEL_MIOPENGROUPCONVBWDWRWS2_SIZE;
extern const char MIOPEN_KERNEL_MIOPENGROUPCONVBWDWRWS2[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVBWDWRW_LXG_P53_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVBWDWRW_LXG_P53[];
extern const size_t MIOPEN_KERNEL_MIOPENGROUPCONVBWDWRW_LXG_P53_SIZE;
extern const char MIOPEN_KERNEL_MIOPENGROUPCONVBWDWRW_LXG_P53[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVBWDWRW_LXG_5X5_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVBWDWRW_LXG_5X5[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVBWDWRW1X1_PAD_READ4_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVBWDWRW1X1_PAD_READ4[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVFWD_LXL_11_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVFWD_LXL_11[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVFFT_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVFFT[];
extern const size_t MIOPEN_KERNEL_MIOPENRNNHIDDENSTATEUPDATE_SIZE;
extern const char MIOPEN_KERNEL_MIOPENRNNHIDDENSTATEUPDATE[];
extern const size_t MIOPEN_KERNEL_BUGZILLA_34765_DETECT_SIZE;
extern const char MIOPEN_KERNEL_BUGZILLA_34765_DETECT[];
extern const size_t MIOPEN_KERNEL_DUMMY_KERNEL_SIZE;
extern const char MIOPEN_KERNEL_DUMMY_KERNEL[];
extern const size_t MIOPEN_KERNEL_CONV3X3_SIZE;
extern const char MIOPEN_KERNEL_CONV3X3[];
extern const size_t MIOPEN_KERNEL_CONV1X1U_SIZE;
extern const char MIOPEN_KERNEL_CONV1X1U[];
extern const size_t MIOPEN_KERNEL_CONV1X1U_STRIDE2_SIZE;
extern const char MIOPEN_KERNEL_CONV1X1U_STRIDE2[];
extern const size_t MIOPEN_KERNEL_CONV1X1U_BIAS_ACTIV_SIZE;
extern const char MIOPEN_KERNEL_CONV1X1U_BIAS_ACTIV[];
extern const size_t MIOPEN_KERNEL_CONV3X3WRW_SIZE;
extern const char MIOPEN_KERNEL_CONV3X3WRW[];
extern const size_t MIOPEN_KERNEL_CONV1X1WRW_SIZE;
extern const char MIOPEN_KERNEL_CONV1X1WRW[];
extern const size_t MIOPEN_KERNEL_CONV5X10U2V2F1_SIZE;
extern const char MIOPEN_KERNEL_CONV5X10U2V2F1[];
extern const size_t MIOPEN_KERNEL_CONV5X10U2V2B1_SIZE;
extern const char MIOPEN_KERNEL_CONV5X10U2V2B1[];
extern const size_t MIOPEN_KERNEL_CONV7X7C3H224W224K64U2V2P3Q3F1_SIZE;
extern const char MIOPEN_KERNEL_CONV7X7C3H224W224K64U2V2P3Q3F1[];
extern const size_t MIOPEN_KERNEL_XFORM_OUT_SIZE;
extern const char MIOPEN_KERNEL_XFORM_OUT[];
extern const size_t MIOPEN_KERNEL_GCNASMBNBWDTRAINSPATIAL_SIZE;
extern const char MIOPEN_KERNEL_GCNASMBNBWDTRAINSPATIAL[];
extern const size_t MIOPEN_KERNEL_MIOPENTENSORKERNELS_SIZE;
extern const char MIOPEN_KERNEL_MIOPENTENSORKERNELS[];
extern const size_t MIOPEN_KERNEL_MIOPENTENSORKERNELSHIP_SIZE;
extern const char MIOPEN_KERNEL_MIOPENTENSORKERNELSHIP[];
extern const size_t MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHSCALARKERNEL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHSCALARKERNEL[];
extern const size_t MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHSUBTENSORKERNEL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHSUBTENSORKERNEL[];
extern const size_t MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHCASTTENSORKERNEL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHCASTTENSORKERNEL[];
extern const size_t MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHTRANSFORMKERNEL_SIZE;
extern const char MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHTRANSFORMKERNEL[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE2_DEC_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE2_DEC[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE2_DIL_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE2_DIL[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE2_DEC_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE2_DEC[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE2_DIL_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE2_DIL[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V16_5_0_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V16_5_0_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_STRIDE_2_DIL_SIZE;
extern const char MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_STRIDE_2_DIL[];
extern const size_t MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_STRIDE_2_DEC_SIZE;
extern const char MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_STRIDE_2_DEC[];
extern const size_t MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_SIZE;
extern const char MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15[];
extern const size_t MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V7_0_3B_SIZE;
extern const char MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V7_0_3B[];
extern const size_t MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V3_0B_SIZE;
extern const char MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V3_0B[];
extern const size_t MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_2_7_SIZE;
extern const char MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_2_7[];
extern const size_t MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_2_7_STRIDE_2_DEC_SIZE;
extern const char MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_2_7_STRIDE_2_DEC[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_DILATION2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_DILATION2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_STRIDE2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_STRIDE2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F3X2_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F3X2_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_DILATION2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_DILATION2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_STRIDE2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_STRIDE2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F3X2_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F3X2_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_DILATION2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_DILATION2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_STRIDE2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_STRIDE2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_DILATION2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_DILATION2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_STRIDE2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_STRIDE2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_DILATION2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_DILATION2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_STRIDE2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_STRIDE2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_DILATION2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_DILATION2[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_STRIDE2_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_STRIDE2[];
extern const size_t MIOPEN_KERNEL_MIOPENCONVBWDBIAS_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCONVBWDBIAS[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMACTIVINFER_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMACTIVINFER[];
extern const size_t MIOPEN_KERNEL_MIOPENBATCHNORMACTIVINFERHIP_SIZE;
extern const char MIOPEN_KERNEL_MIOPENBATCHNORMACTIVINFERHIP[];
extern const size_t MIOPEN_KERNEL_MIOPENCTCLOSS_SIZE;
extern const char MIOPEN_KERNEL_MIOPENCTCLOSS[];
extern const size_t MIOPEN_KERNEL_MIOPENDROPOUTHIP_SIZE;
extern const char MIOPEN_KERNEL_MIOPENDROPOUTHIP[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_FURY_V2_4_1_FP16_FP16ACC_F2X3_C16_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_FURY_V2_4_1_FP16_FP16ACC_F2X3_C16_STRIDE1[];
extern const size_t MIOPEN_KERNEL_CONV_WINOGRAD_FURY_V2_4_1_FP16_FP16ACC_F2X3_C32_STRIDE1_SIZE;
extern const char MIOPEN_KERNEL_CONV_WINOGRAD_FURY_V2_4_1_FP16_FP16ACC_F2X3_C32_STRIDE1[];
extern const size_t MIOPEN_KERNEL_XFORM_DATA_SIZE;
extern const char MIOPEN_KERNEL_XFORM_DATA[];
extern const size_t MIOPEN_KERNEL_XFORM_FILTER_SIZE;
extern const char MIOPEN_KERNEL_XFORM_FILTER[];
extern const size_t MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_DATA_SIZE;
extern const char MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_DATA[];
extern const size_t MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_FILTER_SIZE;
extern const char MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_FILTER[];
extern const size_t MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_OUT_SIZE;
extern const char MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_OUT[];
extern const size_t MIOPEN_KERNEL_UNIVERSALTRANSPOSE_SIZE;
extern const char MIOPEN_KERNEL_UNIVERSALTRANSPOSE[];

// clang-format on
#endif

namespace miopen {

const std::unordered_map<fs::path, std::string_view, FsPathHash>& kernels()
{
    static const std::unordered_map<fs::path, std::string_view, FsPathHash> data{
#ifndef MIOPEN_USE_CLANG_TIDY // Huge generated source
            { "static_kernel_gridwise_convolution_backward_data_implicit_gemm_v1r1_ncdhw_kczyx_nkdhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_NCDHW_KCZYX_NKDHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_NCDHW_KCZYX_NKDHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_data_implicit_gemm_v1r1_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_data_implicit_gemm_v1r1_xdlops_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_XDLOPS_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V1R1_XDLOPS_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_data_implicit_gemm_v4r1_ncdhw_kczyx_nkdhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_NCDHW_KCZYX_NKDHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_NCDHW_KCZYX_NKDHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_data_implicit_gemm_v4r1_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_data_implicit_gemm_v4r1_xdlops_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_XDLOPS_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_DATA_IMPLICIT_GEMM_V4R1_XDLOPS_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_weights_implicit_gemm_v4r4_ncdhw_kczyx_nkdhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_NCDHW_KCZYX_NKDHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_NCDHW_KCZYX_NKDHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_weights_implicit_gemm_v4r4_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_weights_implicit_gemm_v4r4_xdlops_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_convolution_backward_weights_implicit_gemm_v4r4_xdlops_nchw_kcyx_nkhw_padded_gemm.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_PADDED_GEMM, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_BACKWARD_WEIGHTS_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_PADDED_GEMM_SIZE } },
    { "static_kernel_gridwise_convolution_forward_implicit_gemm_v4r4_xdlops_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_convolution_forward_implicit_gemm_v4r4_xdlops_nchw_kcyx_nkhw_padded_gemm.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_PADDED_GEMM, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_PADDED_GEMM_SIZE } },
    { "static_kernel_gridwise_convolution_forward_implicit_gemm_v4r5_xdlops_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R5_XDLOPS_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R5_XDLOPS_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_convolution_implicit_gemm_v4r1_gnchw_gkcyx_gnkhw_lds_double_buffer.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R1_GNCHW_GKCYX_GNKHW_LDS_DOUBLE_BUFFER, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R1_GNCHW_GKCYX_GNKHW_LDS_DOUBLE_BUFFER_SIZE } },
    { "static_kernel_gridwise_convolution_implicit_gemm_v4r1_nchw_kcyx_nkhw_lds_double_buffer.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R1_NCHW_KCYX_NKHW_LDS_DOUBLE_BUFFER, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R1_NCHW_KCYX_NKHW_LDS_DOUBLE_BUFFER_SIZE } },
    { "static_kernel_gridwise_convolution_implicit_gemm_v4r4_ncdhw_kczyx_nkdhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R4_NCDHW_KCZYX_NKDHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R4_NCDHW_KCZYX_NKDHW_SIZE } },
    { "static_kernel_gridwise_convolution_implicit_gemm_v4r4_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R4_NCHW_KCYX_NKHW, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_CONVOLUTION_IMPLICIT_GEMM_V4R4_NCHW_KCYX_NKHW_SIZE } },
    { "static_kernel_gridwise_generic_reduction.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_SIZE } },
    { "static_kernel_gridwise_generic_reduction_first_call.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_SIZE } },
    { "static_kernel_gridwise_generic_reduction_second_call.cpp", { MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL, MIOPEN_KERNEL_STATIC_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_SIZE } },
    { "convolution_forward_implicit_gemm_v4r4_dlops_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_DLOPS_NCHW_KCYX_NKHW, MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_DLOPS_NCHW_KCYX_NKHW_SIZE } },
    { "convolution_forward_implicit_gemm_v4r4_xdlops_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW, MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NCHW_KCYX_NKHW_SIZE } },
    { "convolution_forward_implicit_gemm_v4r4_xdlops_nhwc_kyxc_nhwk.cpp", { MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NHWC_KYXC_NHWK, MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V4R4_XDLOPS_NHWC_KYXC_NHWK_SIZE } },
    { "convolution_forward_implicit_gemm_v6r1_dlops_nchw_kcyx_nkhw.cpp", { MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V6R1_DLOPS_NCHW_KCYX_NKHW, MIOPEN_KERNEL_CONVOLUTION_FORWARD_IMPLICIT_GEMM_V6R1_DLOPS_NCHW_KCYX_NKHW_SIZE } },
    { "gridwise_generic_reduction_first_call_blockwise_reduce_all_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_BLOCKWISE_REDUCE_ALL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_BLOCKWISE_REDUCE_ALL_DIMS_SIZE } },
    { "gridwise_generic_reduction_first_call_blockwise_reduce_partial_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_BLOCKWISE_REDUCE_PARTIAL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_BLOCKWISE_REDUCE_PARTIAL_DIMS_SIZE } },
    { "gridwise_generic_reduction_first_call_multiblock_reduce_all_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_MULTIBLOCK_REDUCE_ALL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_MULTIBLOCK_REDUCE_ALL_DIMS_SIZE } },
    { "gridwise_generic_reduction_first_call_multiblock_reduce_partial_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_MULTIBLOCK_REDUCE_PARTIAL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_MULTIBLOCK_REDUCE_PARTIAL_DIMS_SIZE } },
    { "gridwise_generic_reduction_first_call_threadwise_reduce_all_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_THREADWISE_REDUCE_ALL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_THREADWISE_REDUCE_ALL_DIMS_SIZE } },
    { "gridwise_generic_reduction_first_call_threadwise_reduce_partial_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_THREADWISE_REDUCE_PARTIAL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_THREADWISE_REDUCE_PARTIAL_DIMS_SIZE } },
    { "gridwise_generic_reduction_first_call_warpwise_reduce_all_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_WARPWISE_REDUCE_ALL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_WARPWISE_REDUCE_ALL_DIMS_SIZE } },
    { "gridwise_generic_reduction_first_call_warpwise_reduce_partial_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_WARPWISE_REDUCE_PARTIAL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_FIRST_CALL_WARPWISE_REDUCE_PARTIAL_DIMS_SIZE } },
    { "gridwise_generic_reduction_second_call_blockwise_reduce_all_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_BLOCKWISE_REDUCE_ALL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_BLOCKWISE_REDUCE_ALL_DIMS_SIZE } },
    { "gridwise_generic_reduction_second_call_blockwise_reduce_partial_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_BLOCKWISE_REDUCE_PARTIAL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_BLOCKWISE_REDUCE_PARTIAL_DIMS_SIZE } },
    { "gridwise_generic_reduction_second_call_threadwise_reduce_all_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_THREADWISE_REDUCE_ALL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_THREADWISE_REDUCE_ALL_DIMS_SIZE } },
    { "gridwise_generic_reduction_second_call_threadwise_reduce_partial_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_THREADWISE_REDUCE_PARTIAL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_THREADWISE_REDUCE_PARTIAL_DIMS_SIZE } },
    { "gridwise_generic_reduction_second_call_warpwise_reduce_all_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_WARPWISE_REDUCE_ALL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_WARPWISE_REDUCE_ALL_DIMS_SIZE } },
    { "gridwise_generic_reduction_second_call_warpwise_reduce_partial_dims.cpp", { MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_WARPWISE_REDUCE_PARTIAL_DIMS, MIOPEN_KERNEL_GRIDWISE_GENERIC_REDUCTION_SECOND_CALL_WARPWISE_REDUCE_PARTIAL_DIMS_SIZE } },
    { "igemm_bwd_gtc_dynamic.s", { MIOPEN_KERNEL_IGEMM_BWD_GTC_DYNAMIC, MIOPEN_KERNEL_IGEMM_BWD_GTC_DYNAMIC_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta2x1x1x4_1x8x1x32_tb2x1x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex0_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x1x1x4_1x8x1x32_tb1x1x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex0_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x1x2x4_1x16x1x16_tb1x1x4x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X1X2X4_1X16X1X16_TB1X1X4X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X1X2X4_1X16X1X16_TB1X1X4X4_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex0_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x1x1x4_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x1x4x4_1x16x1x16_tb1x1x2x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X2X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X2X4_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x1x2x4_1x8x1x32_tb1x1x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex1_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex1_bt16x32x4_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x4x1x16_tb1x1x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx16_ex1_bt32x16x4_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x4x1x16_tb1x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX16_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta2x1x1x4_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x1x1x4_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt128x16x8_wt64x16x1_ws1x1_wr1x1_ta1x1x8x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta2x1x1x4_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x1x1x4_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt16x128x8_wt16x64x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt16x256x16_wt4x64x1_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x1x4x4_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x1x2x4_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt256x16x16_wt64x4x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x8_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt32x32x8_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta2x1x2x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt64x8x16_wt64x4x1_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex0_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x16x8_wt64x16x1_ws1x1_wr1x1_ta1x1x8x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt16x128x8_wt16x64x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt16x256x16_wt4x64x1_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt16x32x4_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x4x1x16_tb1x1x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt256x16x16_wt64x4x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x8_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt32x16x4_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x4x1x16_tb1x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt32x32x8_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta2x1x1x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta2x1x2x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt64x8x16_wt64x4x1_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx1_ex1_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta2x1x1x4_1x8x1x32_tb2x1x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X1X4_1X8X1X32_TB2X1X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex0_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x1x1x4_1x8x1x32_tb1x1x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex0_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x1x2x4_1x16x1x16_tb1x1x4x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X1X2X4_1X16X1X16_TB1X1X4X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X1X2X4_1X16X1X16_TB1X1X4X4_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex0_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x1x1x4_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X1X1X4_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x1x4x4_1x16x1x16_tb1x1x2x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X2X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X4X4_1X16X1X16_TB1X1X2X4_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x1x2x4_1x8x1x32_tb1x1x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X2X4_1X8X1X32_TB1X1X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex0_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x4x4_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X4_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X4_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt128x16x8_wt64x16x1_ws1x1_wr1x1_ta1x1x8x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X16X8_WT64X16X1_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt16x128x8_wt16x64x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X128X8_WT16X64X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt16x256x16_wt4x64x1_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X256X16_WT4X64X1_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt16x32x4_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x4x1x16_tb1x1x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt256x16x16_wt64x4x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X16X16_WT64X4X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x8_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt32x16x4_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x4x1x16_tb1x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt32x32x8_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt64x8x16_wt64x4x1_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx4_ex1_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx8_ex1_bt16x32x4_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x4x1x16_tb1x1x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX8_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX8_EX1_BT16X32X4_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X2X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp32_bx8_ex1_bt32x16x4_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x4x1x16_tb1x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX8_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP32_BX8_EX1_BT32X16X4_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x8x1x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x16x1x1_1x2x1x128_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x16x1x1_1x2x1x128_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x16x1x2_1x4x1x64_tb1x16x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x4x1x8_1x16x1x16_tb1x4x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X8_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x1x4_1x8x1x32_tb1x8x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x2x1x8_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x8x1x1_1x2x1x128_tb1x8x1x2_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x8x1x1_1x2x1x128_tb1x8x1x2_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x16x1x1_1x2x1x128_tb1x16x1x2_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X2_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X2_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x2_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X2_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X2_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X4_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x16x1x2_1x4x1x64_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x4x1x8_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x1x4_1x8x1x32_tb1x8x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x2x1x8_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X8_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X8_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x1x2_1x8x1x8_tb1x2x1x2_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X2_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X2_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x4x1x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x2x1x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x2x1x2_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X2_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X2_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x1x2_1x8x1x8_tb1x2x1x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X4_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x4x1x1_1x4x1x16_tb1x4x1x2_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X2_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X2_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x2x1x1_1x4x1x16_tb1x2x1x2_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X2_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X2_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x1x2_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x1x2_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x16x1x2_1x2x1x128_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x1x4_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x2x1x4_1x4x1x64_tb1x2x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x1x2_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x2x1x4_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x1x2_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x4_1x8x1x8_tb1x2x1x2_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X1X2_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X1X2_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x1x2_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x1x2_1x16x1x16_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x2x1x4_1x32x1x8_tb1x2x1x4_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X1X4_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X1X4_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x1x2_1x16x1x16_tb1x4x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x8x1x1_1x8x1x32_tb1x8x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X8X1X1_1X8X1X32_TB1X8X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X8X1X1_1X8X1X32_TB1X8X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x2x1x4_1x16x1x16_tb1x2x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x1x16x1_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta2x1x8x1_1x16x1x16_tb2x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta4x1x4x1_1x8x1x32_tb4x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta8x1x2x1_1x4x1x64_tb8x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x1x16x1_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta2x1x8x1_1x16x1x16_tb2x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta4x1x4x1_1x8x1x32_tb4x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta8x1x2x1_1x4x1x64_tb8x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x4x1x8_1x16x1x16_tb1x4x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta2x1x2x1_1x4x1x64_tb2x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x1x16x1_1x16x1x8_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X8_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x2x1x8_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta2x1x8x1_1x8x1x16_tb2x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA2X1X8X1_1X8X1X16_TB2X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA2X1X8X1_1X8X1X16_TB2X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x16x8_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta2x1x2x1_1x4x1x64_tb2x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x32x8_wt32x8x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x1x16x1_1x32x1x8_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta2x1x8x1_1x16x1x16_tb2x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta4x1x4x1_1x8x1x32_tb4x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta8x1x2x1_1x4x1x64_tb8x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x16x1x2_1x4x1x64_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x4x1x8_1x16x1x16_tb1x4x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x1x4_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta2x1x2x1_1x4x1x64_tb2x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x16x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta2x1x1x1_1x8x1x16_tb2x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X8X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x1x4x1_1x16x1x4_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x1x2_1x8x1x8_tb1x2x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta2x1x2x1_1x8x1x8_tb2x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta4x1x1x1_1x4x1x16_tb4x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta2x1x1x1_1x4x1x16_tb2x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta2x1x1x1_1x8x1x16_tb2x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X2X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x1x4x1_1x16x1x4_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x1x2_1x8x1x8_tb1x2x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X4X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta2x1x2x1_1x8x1x8_tb2x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X4X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta4x1x1x1_1x4x1x16_tb4x1x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X2X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta2x1x1x1_1x4x1x16_tb2x1x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X2X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x1x2_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta4x1x4x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x1x2_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta4x1x4x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x16x1x2_1x2x1x128_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x1x4_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x2x1x4_1x4x1x64_tb1x2x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x1x2_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta2x1x4x1_1x4x1x64_tb2x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x32x8_wt64x4x4_ws1x2_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta4x1x4x1_1x4x1x64_tb4x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x2x1x4_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta2x1x4x1_1x4x1x64_tb2x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x1x4x1_1x16x1x8_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x1x2_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta2x1x2x1_1x8x1x16_tb2x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X16_TB2X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X16_TB2X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x1x8x1_1x16x1x4_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X1X8X1_1X16X1X4_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X1X8X1_1X16X1X4_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x4_1x8x1x8_tb1x2x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x1x2_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta2x1x4x1_1x8x1x8_tb2x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA2X1X4X1_1X8X1X8_TB2X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA2X1X4X1_1X8X1X8_TB2X1X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta4x1x2x1_1x4x1x16_tb4x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA4X1X2X1_1X4X1X16_TB4X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA4X1X2X1_1X4X1X16_TB4X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x8_wt32x8x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x1x4x1_1x8x1x8_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X8X1X8_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta2x1x2x1_1x4x1x16_tb2x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X4X1X16_TB2X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X4X1X16_TB2X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta2x1x1x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x1x4x1_1x32x1x8_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X4X1_1X32X1X8_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X4X1_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x1x2_1x16x1x16_tb1x2x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta2x1x2x1_1x16x1x16_tb2x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA2X1X2X1_1X16X1X16_TB2X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA2X1X2X1_1X16X1X16_TB2X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta4x1x1x1_1x8x1x32_tb4x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA4X1X1X1_1X8X1X32_TB4X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA4X1X1X1_1X8X1X32_TB4X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x1x8x1_1x64x1x4_tb1x1x8x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X1X8X1_1X64X1X4_TB1X1X8X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X1X8X1_1X64X1X4_TB1X1X8X1_1X64X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x2x1x4_1x32x1x8_tb1x2x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X4X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x1x2_1x16x1x16_tb1x4x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta2x1x4x1_1x32x1x8_tb2x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA2X1X4X1_1X32X1X8_TB2X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA2X1X4X1_1X32X1X8_TB2X1X4X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta4x1x2x1_1x16x1x16_tb4x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA4X1X2X1_1X16X1X16_TB4X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA4X1X2X1_1X16X1X16_TB4X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta8x1x1x1_1x8x1x32_tb8x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA8X1X1X1_1X8X1X32_TB8X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA8X1X1X1_1X8X1X32_TB8X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta2x1x1x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta2x1x2x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta4x1x1x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta4x1x1x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x1x8x1_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X1X8X1_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X1X8X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x2x1x4_1x16x1x16_tb1x2x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x1x2_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta2x1x4x1_1x16x1x16_tb2x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA2X1X4X1_1X16X1X16_TB2X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA2X1X4X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta4x1x2x1_1x8x1x32_tb4x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA4X1X2X1_1X8X1X32_TB4X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA4X1X2X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta8x1x1x1_1x4x1x64_tb8x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA8X1X1X1_1X4X1X64_TB8X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA8X1X1X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta2x1x1x1_1x4x1x64_tb2x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta4x1x1x1_1x4x1x64_tb4x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta4x1x1x1_1x4x1x64_tb4x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x2x1x4_1x16x1x16_tb1x2x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X16X1X16_TB1X2X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta2x1x1x1_1x4x1x64_tb2x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta2x1x2x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta4x1x1x1_1x4x1x64_tb4x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta2x1x1x1_1x4x1x64_tb2x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt64x8x16_wt64x4x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx1_ex1_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x8x1x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x16x1x1_1x2x1x128_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x16x1x1_1x2x1x128_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x16x1x2_1x4x1x64_tb1x16x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x4x1x8_1x16x1x16_tb1x4x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X8_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x1x4_1x8x1x32_tb1x8x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x2x1x8_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x8x1x1_1x2x1x128_tb1x8x1x2_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x8x1x1_1x2x1x128_tb1x8x1x2_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X8X1X1_1X2X1X128_TB1X8X1X2_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x16x1x1_1x2x1x128_tb1x16x1x2_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X2_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X16X1X1_1X2X1X128_TB1X16X1X2_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x2_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X2_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X2_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X1X4_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x16x1x2_1x4x1x64_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x4x1x8_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x1x4_1x8x1x32_tb1x8x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x2x1x8_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X8_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X8_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x1x2_1x8x1x8_tb1x2x1x2_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X2_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X2_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x4x1x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x2x1x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x2x1x2_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X2_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X2X1X2_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x1x2_1x8x1x8_tb1x2x1x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X1X4_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x4x1x1_1x4x1x16_tb1x4x1x2_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X2_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X4X1X16_TB1X4X1X2_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x2x1x1_1x4x1x16_tb1x2x1x2_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X2_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X4X1X16_TB1X2X1X2_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x1x2_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x1x2_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x16x1x2_1x2x1x128_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x1x4_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x2x1x4_1x4x1x64_tb1x2x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x1x2_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x2x1x4_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x1x2_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x4_1x8x1x8_tb1x2x1x2_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X1X2_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X1X2_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x1x2_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x1x2_1x16x1x16_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x2x1x4_1x32x1x8_tb1x2x1x4_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X1X4_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X1X4_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x1x2_1x16x1x16_tb1x4x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x8x1x1_1x8x1x32_tb1x8x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X8X1X1_1X8X1X32_TB1X8X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X8X1X1_1X8X1X32_TB1X8X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x2x1x4_1x16x1x16_tb1x2x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X8_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x1x16x1_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta2x1x8x1_1x16x1x16_tb2x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta4x1x4x1_1x8x1x32_tb4x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta8x1x2x1_1x4x1x64_tb8x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x1x16x1_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta2x1x8x1_1x16x1x16_tb2x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta4x1x4x1_1x8x1x32_tb4x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta8x1x2x1_1x4x1x64_tb8x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x4x1x8_1x16x1x16_tb1x4x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta2x1x2x1_1x4x1x64_tb2x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x1x16x1_1x16x1x8_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X8_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x2x1x8_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X8_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta2x1x8x1_1x8x1x16_tb2x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA2X1X8X1_1X8X1X16_TB2X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA2X1X8X1_1X8X1X16_TB2X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x16x8_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta2x1x2x1_1x4x1x64_tb2x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x32x8_wt32x8x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x2x1x4_1x8x1x32_tb1x2x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X2X1X4_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta2x1x4x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA2X1X4X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta4x1x2x1_1x4x1x64_tb4x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA4X1X2X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x1x16x1_1x32x1x8_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X16X1_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x2x1x8_1x16x1x16_tb1x2x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X2X1X8_1X16X1X16_TB1X2X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x1x2_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X1X2_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta2x1x8x1_1x16x1x16_tb2x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA2X1X8X1_1X16X1X16_TB2X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta4x1x4x1_1x8x1x32_tb4x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA4X1X4X1_1X8X1X32_TB4X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta8x1x2x1_1x4x1x64_tb8x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA8X1X2X1_1X4X1X64_TB8X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x16x1x2_1x4x1x64_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X16X1X2_1X4X1X64_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x4x1x8_1x16x1x16_tb1x4x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X4X1X8_1X16X1X16_TB1X4X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x1x4_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X1X4_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x1x2_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X1X2_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta2x1x2x1_1x4x1x64_tb2x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA2X1X2X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x16x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta2x1x1x1_1x8x1x16_tb2x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X8X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x1x4x1_1x16x1x4_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x1x2_1x8x1x8_tb1x2x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta2x1x2x1_1x8x1x8_tb2x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta4x1x1x1_1x4x1x16_tb4x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta2x1x1x1_1x4x1x16_tb2x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta2x1x1x1_1x8x1x16_tb2x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X16_TB2X1X2X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x1x4x1_1x16x1x4_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X1X4X1_1X16X1X4_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x1x2_1x8x1x8_tb1x2x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X2_1X8X1X8_TB1X2X4X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta2x1x2x1_1x8x1x8_tb2x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA2X1X2X1_1X8X1X8_TB2X1X4X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta4x1x1x1_1x4x1x16_tb4x1x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA4X1X1X1_1X4X1X16_TB4X1X2X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta2x1x1x1_1x4x1x16_tb2x1x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X4X1X16_TB2X1X2X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x1x2_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta4x1x4x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x1x2_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X1X2_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta4x1x4x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x16x1x2_1x2x1x128_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X16X1X2_1X2X1X128_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x1x4_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X1X4_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x2x1x4_1x4x1x64_tb1x2x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x1x2_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X1X2_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta2x1x4x1_1x4x1x64_tb2x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x32x8_wt64x4x4_ws1x2_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta2x1x8x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA2X1X8X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta4x1x4x1_1x4x1x64_tb4x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA4X1X4X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x2x1x4_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X2X1X4_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta2x1x4x1_1x4x1x64_tb2x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA2X1X4X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x1x4x1_1x16x1x8_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X8_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x1x2_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X1X2_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta2x1x2x1_1x8x1x16_tb2x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X16_TB2X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA2X1X2X1_1X8X1X16_TB2X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x1x8x1_1x16x1x4_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X1X8X1_1X16X1X4_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X1X8X1_1X16X1X4_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x4_1x8x1x8_tb1x2x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X4_1X8X1X8_TB1X2X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x1x2_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta2x1x4x1_1x8x1x8_tb2x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA2X1X4X1_1X8X1X8_TB2X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA2X1X4X1_1X8X1X8_TB2X1X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta4x1x2x1_1x4x1x16_tb4x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA4X1X2X1_1X4X1X16_TB4X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA4X1X2X1_1X4X1X16_TB4X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x8_wt32x8x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x1x4x1_1x8x1x8_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X8X1X8_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta2x1x2x1_1x4x1x16_tb2x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X4X1X16_TB2X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X4X1X16_TB2X1X1X1_1X4X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta2x1x1x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA2X1X1X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta2x1x1x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x1x4x1_1x32x1x8_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X4X1_1X32X1X8_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X4X1_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x1x2_1x16x1x16_tb1x2x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X1X2_1X16X1X16_TB1X2X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta2x1x2x1_1x16x1x16_tb2x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA2X1X2X1_1X16X1X16_TB2X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA2X1X2X1_1X16X1X16_TB2X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta4x1x1x1_1x8x1x32_tb4x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA4X1X1X1_1X8X1X32_TB4X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA4X1X1X1_1X8X1X32_TB4X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x1x8x1_1x64x1x4_tb1x1x8x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X1X8X1_1X64X1X4_TB1X1X8X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X1X8X1_1X64X1X4_TB1X1X8X1_1X64X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x2x1x4_1x32x1x8_tb1x2x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X2X1X4_1X32X1X8_TB1X2X4X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x1x2_1x16x1x16_tb1x4x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X1X2_1X16X1X16_TB1X4X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta2x1x4x1_1x32x1x8_tb2x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA2X1X4X1_1X32X1X8_TB2X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA2X1X4X1_1X32X1X8_TB2X1X4X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta4x1x2x1_1x16x1x16_tb4x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA4X1X2X1_1X16X1X16_TB4X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA4X1X2X1_1X16X1X16_TB4X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta8x1x1x1_1x8x1x32_tb8x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA8X1X1X1_1X8X1X32_TB8X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA8X1X1X1_1X8X1X32_TB8X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta2x1x1x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA2X1X1X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta2x1x2x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta4x1x1x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta4x1x1x1_1x4x1x64_tb4x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x1x8x1_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X1X8X1_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X1X8X1_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x2x1x4_1x16x1x16_tb1x2x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x1x2_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta2x1x4x1_1x16x1x16_tb2x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA2X1X4X1_1X16X1X16_TB2X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA2X1X4X1_1X16X1X16_TB2X1X8X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta4x1x2x1_1x8x1x32_tb4x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA4X1X2X1_1X8X1X32_TB4X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA4X1X2X1_1X8X1X32_TB4X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta8x1x1x1_1x4x1x64_tb8x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA8X1X1X1_1X4X1X64_TB8X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA8X1X1X1_1X4X1X64_TB8X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta2x1x1x1_1x4x1x64_tb2x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta4x1x1x1_1x4x1x64_tb4x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta4x1x1x1_1x4x1x64_tb4x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x2x1x4_1x16x1x16_tb1x2x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X16X1X16_TB1X2X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X2X1X4_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta2x1x1x1_1x4x1x64_tb2x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta2x1x2x1_1x8x1x32_tb2x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA2X1X2X1_1X8X1X32_TB2X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x1x2_1x8x1x32_tb1x2x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X1X2_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta2x1x2x1_1x8x1x32_tb2x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA2X1X2X1_1X8X1X32_TB2X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta4x1x1x1_1x4x1x64_tb4x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA4X1X1X1_1X4X1X64_TB4X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta2x1x1x1_1x4x1x64_tb2x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA2X1X1X1_1X4X1X64_TB2X1X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt64x8x16_wt64x4x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_bwd_gtcx_nchw_fp16_bx4_ex1_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx16_ex0_bt16x16x4_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x4x1x16_tb1x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX16_EX0_BT16X16X4_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX16_EX0_BT16X16X4_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx16_ex1_bt16x16x4_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x4x1x16_tb1x1x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX16_EX1_BT16X16X4_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX16_EX1_BT16X16X4_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X4X1X16_TB1X1X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x64x32_wt32x8x1_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X32_WT32X8X1_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X32_WT32X8X1_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x64x4_wt32x8x1_ws1x2_wr2x2_ta1x2x1x1_1x2x1x128_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x4x1x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x32x16_wt8x32x1_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x32x16_wt8x32x1_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x32x8_wt8x32x1_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x32x8_wt8x32x1_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x64x16_wt4x64x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x64x16_wt4x64x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x4x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x64x8_wt4x64x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt16x64x8_wt4x64x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x2x2x1_1x2x1x128_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x128x32_wt8x32x1_ws1x1_wr2x2_ta1x4x1x1_1x8x1x32_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X32_WT8X32X1_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X32_WT8X32X1_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x128x8_wt8x32x1_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x128x8_wt8x32x1_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x16x16_wt32x8x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x16x16_wt32x8x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x16x8_wt32x8x1_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x16x8_wt32x8x1_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x32x16_wt16x16x1_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x32x16_wt16x16x1_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x4x4x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x128x32_wt8x32x1_ws2x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X32_WT8X32X1_WS2X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X32_WT8X32X1_WS2X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x128x4_wt8x32x1_ws2x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x128x4_wt8x32x1_ws2x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x2x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x16x16_wt64x4x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x16x16_wt64x4x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x16x8_wt64x4x1_ws1x2_wr1x1_ta1x4x1x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x256x4_wt16x64x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x256x4_wt16x64x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x4x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x2x1x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x64x64_wt16x16x1_ws1x1_wr2x2_ta1x4x1x4_1x16x1x16_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X64_WT16X16X1_WS1X1_WR2X2_TA1X4X1X4_1X16X1X16_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X64_WT16X16X1_WS1X1_WR2X2_TA1X4X1X4_1X16X1X16_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt64x8x16_wt64x4x1_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex0_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x4x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x64x32_wt32x8x1_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X32_WT32X8X1_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X32_WT32X8X1_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x64x4_wt32x8x1_ws1x2_wr2x2_ta1x2x1x1_1x2x1x128_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x4x1x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x32x16_wt8x32x1_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x32x16_wt8x32x1_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x32x8_wt8x32x1_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x32x8_wt8x32x1_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x64x16_wt4x64x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x64x16_wt4x64x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x4x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x64x8_wt4x64x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt16x64x8_wt4x64x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x2x2x1_1x2x1x128_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x128x8_wt8x32x1_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x128x8_wt8x32x1_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x16x16_wt32x8x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x16x16_wt32x8x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x16x8_wt32x8x1_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x16x8_wt32x8x1_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x32x16_wt16x16x1_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x32x16_wt16x16x1_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x4x4x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x128x4_wt8x32x1_ws2x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x128x4_wt8x32x1_ws2x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x2x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x16x16_wt64x4x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x16x16_wt64x4x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x16x8_wt64x4x1_ws1x2_wr1x1_ta1x4x1x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x256x4_wt16x64x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x256x4_wt16x64x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x4x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x2x1x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt64x8x16_wt64x4x1_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx1_ex1_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x4x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX1_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx32_ex0_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x8x2x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX32_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X8X2X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX32_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X8X2X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x64x4_wt32x8x1_ws1x2_wr2x2_ta1x2x1x1_1x2x1x128_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x4x1x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x32x16_wt8x32x1_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x32x16_wt8x32x1_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x32x8_wt8x32x1_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x32x8_wt8x32x1_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x64x16_wt4x64x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x64x16_wt4x64x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x4x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x64x8_wt4x64x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt16x64x8_wt4x64x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x2x2x1_1x2x1x128_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x128x8_wt8x32x1_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x128x8_wt8x32x1_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x16x16_wt32x8x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x16x16_wt32x8x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x16x8_wt32x8x1_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x16x8_wt32x8x1_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x32x16_wt16x16x1_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x32x16_wt16x16x1_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x4x4x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x128x4_wt8x32x1_ws2x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x128x4_wt8x32x1_ws2x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x2x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x16x16_wt64x4x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x16x16_wt64x4x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x16x8_wt64x4x1_ws1x2_wr1x1_ta1x4x1x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x256x4_wt16x64x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x256x4_wt16x64x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x4x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x2x1x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt64x8x16_wt64x4x1_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex0_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x4x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX0_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x256x16_wt32x64x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X16_WT32X64X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x256x8_wt32x64x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X256X8_WT32X64X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x64x4_wt32x8x1_ws1x2_wr2x2_ta1x2x1x1_1x2x1x128_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X4_WT32X8X1_WS1X2_WR2X2_TA1X2X1X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x4x1x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x4x1x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X4X1X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x32x16_wt8x32x1_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x32x16_wt8x32x1_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x2x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X2X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x32x8_wt8x32x1_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x32x8_wt8x32x1_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x64x16_wt4x64x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x64x16_wt4x64x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x16_tb1x4x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X16_WT4X64X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X16_TB1X4X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x64x8_wt4x64x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt16x64x8_wt4x64x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT16X64X8_WT4X64X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x2x2x1_1x2x1x128_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X2X2X1_1X2X1X128_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x128x16_wt8x32x1_ws1x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X16_WT8X32X1_WS1X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x128x8_wt8x32x1_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x128x8_wt8x32x1_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X128X8_WT8X32X1_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x16x16_wt32x8x1_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x16x16_wt32x8x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x16x16_wt32x8x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X16_WT32X8X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x16x8_wt32x8x1_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x16x8_wt32x8x1_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X16X8_WT32X8X1_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x256x16_wt4x64x1_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X16_WT4X64X1_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x256x8_wt4x64x1_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X256X8_WT4X64X1_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x32x16_wt16x16x1_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x32x16_wt16x16x1_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X32X16_WT16X16X1_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x64x16_wt8x32x1_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X16_WT8X32X1_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt32x64x8_wt8x32x1_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT32X64X8_WT8X32X1_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x4x4x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X4X4X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x128x4_wt8x32x1_ws2x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x128x4_wt8x32x1_ws2x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x2x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X4_WT8X32X1_WS2X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X2X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x16x16_wt64x4x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x16x16_wt64x4x1_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x16x8_wt64x4x1_ws1x2_wr1x1_ta1x4x1x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X16X8_WT64X4X1_WS1X2_WR1X1_TA1X4X1X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x256x4_wt16x64x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x256x4_wt16x64x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x4x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X4_WT16X64X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X4X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x4x2x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X4X2X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x2x1x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X2X1X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x2x1x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X2X1X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt64x8x16_wt64x4x1_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx4_ex1_bt8x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x4x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX4_EX1_BT8X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X4X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx64_ex0_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x16x1x1_1x1x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX64_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX64_EX0_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx64_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x16x1x1_1x1x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX64_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX64_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp32_bx8_ex1_bt64x8x16_wt64x4x1_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX8_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP32_BX8_EX1_BT64X8X16_WT64X4X1_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x32x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x16x8_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x32x8_wt32x8x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x16x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x8x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x8x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x2x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x32x8_wt64x4x4_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x16x8_wt32x8x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x8x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x16x1x1_1x1x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x16x8_wt64x4x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x32_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex0_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x32x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x16x8_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x32x8_wt32x8x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x16x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x8x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x8x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x2x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x32x8_wt64x4x4_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x16x8_wt32x8x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x8x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x16x1x1_1x1x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x16x8_wt64x4x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x32_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx16_ex1_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX16_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x1x32x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x32x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x16x8_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x32x8_wt32x8x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x16x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x16x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x8x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x8x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x2x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x32x8_wt64x4x4_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x8_wt32x8x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x1x8x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x8x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x16x1x1_1x1x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x16x8_wt64x4x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x32_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x32_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt64x8x16_wt64x4x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex0_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x1x32x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x32x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x16x8_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x32x8_wt32x8x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x16x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x16x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x8x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x8x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x2x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x32x8_wt64x4x4_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x8_wt32x8x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x1x8x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x8x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x16x1x1_1x1x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x16x8_wt64x4x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x32_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x32_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt64x8x16_wt64x4x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx1_ex1_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX1_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x1x32x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x32x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x16x8_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x32x8_wt32x8x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x16x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x16x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x8x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x8x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x2x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x32x8_wt64x4x4_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x8_wt32x8x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x1x8x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x8x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x16x1x1_1x1x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x16x8_wt64x4x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x32_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x32_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt64x8x16_wt64x4x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex0_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX0_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x64x4_ws2x1_wr1x1_ta1x4x2x1_1x4x1x64_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X64X4_WS2X1_WR1X1_TA1X4X2X1_1X4X1X64_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt16x16x16_ws2x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT16X16X16_WS2X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x1x32x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X32X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x64_wt16x16x16_ws2x2_wr2x2_ta1x8x4x1_1x8x1x32_tb1x32x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X64_WT16X16X16_WS2X2_WR2X2_TA1X8X4X1_1X8X1X32_TB1X32X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x128x8_wt32x64x4_ws2x1_wr1x1_ta1x2x2x1_1x4x1x64_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X128X8_WT32X64X4_WS2X1_WR1X1_TA1X2X2X1_1X4X1X64_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x16x16_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x64_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X64_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x16x8_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x2x1x64_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X16X8_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X2X1X64_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x64x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X64X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x256x8_wt32x64x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X256X8_WT32X64X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x32x16_wt32x8x4_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT32X8X4_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x32x8_wt32x8x4_ws1x1_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X32X8_WT32X8X4_WS1X1_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x64_wt16x16x16_ws2x1_wr2x2_ta1x8x4x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X64_WT16X16X16_WS2X1_WR2X2_TA1X8X4X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt128x64x8_wt32x8x4_ws1x2_wr2x2_ta1x2x2x1_1x4x1x64_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT128X64X8_WT32X8X4_WS1X2_WR2X2_TA1X2X2X1_1X4X1X64_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x16x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X16X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x16x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X16X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x8x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X8X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x8x1x1_1x1x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X8X1X1_1X1X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x16_wt16x16x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X16_WT16X16X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x16x8_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X16X8_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x1x8x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X1X8X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x16_wt8x32x4_ws2x1_wr1x1_ta1x2x2x1_1x8x1x8_tb1x8x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X16_WT8X32X4_WS2X1_WR1X1_TA1X2X2X1_1X8X1X8_TB1X8X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x8_wt8x32x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x2x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X2X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x1x4x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X1X4X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x32x8_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x8x1x8_tb1x4x1x1_1x2x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X32X8_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X8X1X8_TB1X4X1X1_1X2X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x64x16_wt4x64x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt16x64x8_wt4x64x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x4x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT16X64X8_WT4X64X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X4X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x32x8_wt64x4x4_ws1x2_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X32X8_WT64X4X4_WS1X2_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt64x16x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT64X16X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x16_wt8x32x4_ws1x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT8X32X4_WS1X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x8_wt16x64x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT16X64X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x128x8_wt8x32x4_ws1x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X128X8_WT8X32X4_WS1X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x16_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X16_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x1x4x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X1X4X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x16_wt32x8x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x16_tb1x4x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X16_WT32X8X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X16_TB1X4X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x8_wt32x8x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x1x2x1_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X1X2X1_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x16x8_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x16_tb1x2x1x1_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X16X8_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X16_TB1X2X1X1_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x2x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X2X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x256x8_wt4x64x4_ws2x1_wr2x2_ta1x1x1x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X256X8_WT4X64X4_WS2X1_WR2X2_TA1X1X1X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x2x2x1_1x16x1x16_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X2X2X1_1X16X1X16_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x1x8x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X1X8X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x64_wt16x16x16_ws1x1_wr1x1_ta1x4x2x1_1x16x1x16_tb1x8x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X64_WT16X16X16_WS1X1_WR1X1_TA1X4X2X1_1X16X1X16_TB1X8X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x2x1_1x16x1x16_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X2X1_1X16X1X16_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x16x1x1_1x1x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X16X1X1_1X1X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt32x32x8_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X32X8_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt32x64x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT32X64X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt64x32x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT64X32X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x16x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X16X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt32x32x8_ws1x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT32X32X8_WS1X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x8_wt32x64x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT32X64X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x8_wt64x32x4_ws1x1_wr1x1_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT64X32X4_WS1X1_WR1X1_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x128x8_wt8x32x4_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X128X8_WT8X32X4_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x2x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X2X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x16x16_wt64x4x4_ws1x2_wr1x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X2_WR1X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x16x8_wt64x4x4_ws1x2_wr1x1_ta1x2x2x1_1x4x1x32_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X16X8_WT64X4X4_WS1X2_WR1X1_TA1X2X2X1_1X4X1X32_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt16x64x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT16X64X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x16x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X16X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x64x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X64X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x32x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X32X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x8_wt16x64x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT16X64X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x256x8_wt32x64x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x8x1x1_1x1x1x256.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X256X8_WT32X64X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X8X1X1_1X1X1X256_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x2x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X2X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x8x2x1_1x2x1x32_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X8X2X1_1X2X1X32_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x2x2x1_1x8x1x32_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X2X2X1_1X8X1X32_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x32_wt16x16x16_ws2x2_wr1x1_ta1x4x2x1_1x8x1x32_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS2X2_WR1X1_TA1X4X2X1_1X8X1X32_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x16x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X16X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x64_wt16x16x16_ws2x2_wr1x1_ta1x8x2x1_1x8x1x32_tb1x1x16x1_1x64x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X64_WT16X16X16_WS2X2_WR1X1_TA1X8X2X1_1X8X1X32_TB1X1X16X1_1X64X1X4_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x2x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X2X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt64x8x16_wt64x4x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x1x1x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT64X8X16_WT64X4X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X1X1X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x1x8x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X1X8X1_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcx_nchw_fp16_bx4_ex1_bt8x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x8_tb1x8x1x1_1x2x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NCHW_FP16_BX4_EX1_BT8X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X8_TB1X8X1X1_1X2X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt128x128x32_lt8x8_lw2x4_lr2x4_ta1x1x1x16_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt128x160x32_lt8x8_lw4x2_lr2x5_ta1x1x1x16_1x8x1x32_tb1x1x5x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt128x192x32_lt8x8_lw2x4_lr2x6_ta1x1x1x16_1x8x1x32_tb1x1x6x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt128x224x32_lt8x8_lw4x2_lr2x7_ta1x1x1x16_1x8x1x32_tb1x1x7x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt128x256x32_lt8x8_lw2x4_lr2x8_ta1x1x1x16_1x8x1x32_tb1x1x8x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt128x32x32_lt8x8_lw4x1_lr2x2_ta1x1x1x32_1x8x1x16_tb1x1x2x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt128x64x32_lt8x8_lw4x2_lr2x2_ta1x1x1x16_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt128x96x32_lt8x8_lw4x2_lr2x3_ta1x1x1x16_1x8x1x32_tb1x1x3x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt160x128x32_lt8x8_lw2x4_lr5x2_ta1x1x1x20_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt160x64x32_lt8x8_lw2x4_lr5x1_ta1x1x1x20_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt192x128x32_lt8x8_lw2x4_lr3x4_ta1x1x1x24_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt192x64x32_lt8x8_lw2x4_lr3x2_ta1x1x1x24_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt224x128x32_lt8x8_lw2x4_lr7x2_ta1x1x1x28_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt256x128x32_lt8x8_lw4x2_lr2x8_ta1x1x1x32_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt32x128x32_lt8x8_lw1x4_lr2x2_ta1x1x1x8_1x8x1x16_tb1x1x8x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt32x32x32_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x8x1x4_tb1x1x8x4_1x8x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt32x64x32_lt8x8_lw2x4_lr2x2_ta1x1x1x16_1x8x1x8_tb1x1x8x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt64x128x32_lt8x8_lw2x4_lr2x2_ta1x1x1x8_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt64x160x32_lt8x8_lw4x2_lr1x5_ta1x1x1x8_1x8x1x32_tb1x1x5x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt64x192x32_lt8x8_lw2x4_lr1x6_ta1x1x1x8_1x8x1x32_tb1x1x6x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt64x32x32_lt8x8_lw4x2_lr2x2_ta1x1x1x32_1x8x1x8_tb1x1x4x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt64x64x32_lt8x8_lw2x2_lr2x2_ta1x1x1x16_1x8x1x16_tb1x1x4x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt64x64x64_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x16x1x8_tb1x1x8x4_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt96x128x32_lt8x8_lw4x2_lr3x2_ta1x1x1x12_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex0_bt96x96x32_lt8x8_lw2x2_lr3x3_ta1x1x1x24_1x8x1x16_tb1x1x6x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt128x128x32_lt8x8_lw2x4_lr2x4_ta1x1x1x16_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt128x160x32_lt8x8_lw4x2_lr2x5_ta1x1x1x16_1x8x1x32_tb1x1x5x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt128x192x32_lt8x8_lw2x4_lr2x6_ta1x1x1x16_1x8x1x32_tb1x1x6x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt128x224x32_lt8x8_lw4x2_lr2x7_ta1x1x1x16_1x8x1x32_tb1x1x7x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt128x256x32_lt8x8_lw2x4_lr2x8_ta1x1x1x16_1x8x1x32_tb1x1x8x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt128x32x32_lt8x8_lw4x1_lr2x2_ta1x1x1x32_1x8x1x16_tb1x1x2x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt128x64x32_lt8x8_lw4x2_lr2x2_ta1x1x1x16_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt128x96x32_lt8x8_lw4x2_lr2x3_ta1x1x1x16_1x8x1x32_tb1x1x3x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt160x128x32_lt8x8_lw2x4_lr5x2_ta1x1x1x20_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt160x64x32_lt8x8_lw2x4_lr5x1_ta1x1x1x20_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt192x128x32_lt8x8_lw2x4_lr3x4_ta1x1x1x24_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt192x64x32_lt8x8_lw2x4_lr3x2_ta1x1x1x24_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt224x128x32_lt8x8_lw2x4_lr7x2_ta1x1x1x28_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt256x128x32_lt8x8_lw4x2_lr2x8_ta1x1x1x32_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt32x128x32_lt8x8_lw1x4_lr2x2_ta1x1x1x8_1x8x1x16_tb1x1x8x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt32x32x32_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x8x1x4_tb1x1x8x4_1x8x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt32x64x32_lt8x8_lw2x4_lr2x2_ta1x1x1x16_1x8x1x8_tb1x1x8x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt64x128x32_lt8x8_lw2x4_lr2x2_ta1x1x1x8_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt64x160x32_lt8x8_lw4x2_lr1x5_ta1x1x1x8_1x8x1x32_tb1x1x5x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt64x192x32_lt8x8_lw2x4_lr1x6_ta1x1x1x8_1x8x1x32_tb1x1x6x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt64x32x32_lt8x8_lw4x2_lr2x2_ta1x1x1x32_1x8x1x8_tb1x1x4x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt64x64x32_lt8x8_lw2x2_lr2x2_ta1x1x1x16_1x8x1x16_tb1x1x4x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt64x64x64_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x16x1x8_tb1x1x8x4_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt96x128x32_lt8x8_lw4x2_lr3x2_ta1x1x1x12_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x4_bx0_ex1_bt96x96x32_lt8x8_lw2x2_lr3x3_ta1x1x1x24_1x8x1x16_tb1x1x6x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X4_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt128x128x32_lt8x8_lw2x4_lr2x4_ta1x1x1x16_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt128x160x32_lt8x8_lw4x2_lr2x5_ta1x1x1x16_1x8x1x32_tb1x1x5x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt128x192x32_lt8x8_lw2x4_lr2x6_ta1x1x1x16_1x8x1x32_tb1x1x6x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt128x224x32_lt8x8_lw4x2_lr2x7_ta1x1x1x16_1x8x1x32_tb1x1x7x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt128x256x32_lt8x8_lw2x4_lr2x8_ta1x1x1x16_1x8x1x32_tb1x1x8x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt128x32x32_lt8x8_lw4x1_lr2x2_ta1x1x1x32_1x8x1x16_tb1x1x2x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt128x64x32_lt8x8_lw4x2_lr2x2_ta1x1x1x16_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt128x96x32_lt8x8_lw4x2_lr2x3_ta1x1x1x16_1x8x1x32_tb1x1x3x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt160x128x32_lt8x8_lw2x4_lr5x2_ta1x1x1x20_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt160x64x32_lt8x8_lw2x4_lr5x1_ta1x1x1x20_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt192x128x32_lt8x8_lw2x4_lr3x4_ta1x1x1x24_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt192x64x32_lt8x8_lw2x4_lr3x2_ta1x1x1x24_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt224x128x32_lt8x8_lw2x4_lr7x2_ta1x1x1x28_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt256x128x32_lt8x8_lw4x2_lr2x8_ta1x1x1x32_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt32x128x32_lt8x8_lw1x4_lr2x2_ta1x1x1x8_1x8x1x16_tb1x1x8x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt32x32x32_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x8x1x4_tb1x1x8x4_1x8x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt32x64x32_lt8x8_lw2x4_lr2x2_ta1x1x1x16_1x8x1x8_tb1x1x8x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt64x128x32_lt8x8_lw2x4_lr2x2_ta1x1x1x8_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt64x160x32_lt8x8_lw4x2_lr1x5_ta1x1x1x8_1x8x1x32_tb1x1x5x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt64x192x32_lt8x8_lw2x4_lr1x6_ta1x1x1x8_1x8x1x32_tb1x1x6x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt64x32x32_lt8x8_lw4x2_lr2x2_ta1x1x1x32_1x8x1x8_tb1x1x4x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt64x64x32_lt8x8_lw2x2_lr2x2_ta1x1x1x16_1x8x1x16_tb1x1x4x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt64x64x64_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x16x1x8_tb1x1x8x4_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt96x128x32_lt8x8_lw4x2_lr3x2_ta1x1x1x12_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex0_bt96x96x32_lt8x8_lw2x2_lr3x3_ta1x1x1x24_1x8x1x16_tb1x1x6x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt128x128x32_lt8x8_lw2x4_lr2x4_ta1x1x1x16_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt128x160x32_lt8x8_lw4x2_lr2x5_ta1x1x1x16_1x8x1x32_tb1x1x5x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X160X32_LT8X8_LW4X2_LR2X5_TA1X1X1X16_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt128x192x32_lt8x8_lw2x4_lr2x6_ta1x1x1x16_1x8x1x32_tb1x1x6x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt128x224x32_lt8x8_lw4x2_lr2x7_ta1x1x1x16_1x8x1x32_tb1x1x7x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X224X32_LT8X8_LW4X2_LR2X7_TA1X1X1X16_1X8X1X32_TB1X1X7X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt128x256x32_lt8x8_lw2x4_lr2x8_ta1x1x1x16_1x8x1x32_tb1x1x8x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X8X1X32_TB1X1X8X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt128x32x32_lt8x8_lw4x1_lr2x2_ta1x1x1x32_1x8x1x16_tb1x1x2x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X2X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt128x64x32_lt8x8_lw4x2_lr2x2_ta1x1x1x16_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt128x96x32_lt8x8_lw4x2_lr2x3_ta1x1x1x16_1x8x1x32_tb1x1x3x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT128X96X32_LT8X8_LW4X2_LR2X3_TA1X1X1X16_1X8X1X32_TB1X1X3X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt160x128x32_lt8x8_lw2x4_lr5x2_ta1x1x1x20_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT160X128X32_LT8X8_LW2X4_LR5X2_TA1X1X1X20_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt160x64x32_lt8x8_lw2x4_lr5x1_ta1x1x1x20_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT160X64X32_LT8X8_LW2X4_LR5X1_TA1X1X1X20_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt192x128x32_lt8x8_lw2x4_lr3x4_ta1x1x1x24_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt192x64x32_lt8x8_lw2x4_lr3x2_ta1x1x1x24_1x8x1x32_tb1x1x2x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X2X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt224x128x32_lt8x8_lw2x4_lr7x2_ta1x1x1x28_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT224X128X32_LT8X8_LW2X4_LR7X2_TA1X1X1X28_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt256x128x32_lt8x8_lw4x2_lr2x8_ta1x1x1x32_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt32x128x32_lt8x8_lw1x4_lr2x2_ta1x1x1x8_1x8x1x16_tb1x1x8x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X8X1X16_TB1X1X8X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt32x32x32_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x8x1x4_tb1x1x8x4_1x8x1x4.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X4_TB1X1X8X4_1X8X1X4_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt32x64x32_lt8x8_lw2x4_lr2x2_ta1x1x1x16_1x8x1x8_tb1x1x8x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X8X1X8_TB1X1X8X4_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt64x128x32_lt8x8_lw2x4_lr2x2_ta1x1x1x8_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt64x160x32_lt8x8_lw4x2_lr1x5_ta1x1x1x8_1x8x1x32_tb1x1x5x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X160X32_LT8X8_LW4X2_LR1X5_TA1X1X1X8_1X8X1X32_TB1X1X5X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt64x192x32_lt8x8_lw2x4_lr1x6_ta1x1x1x8_1x8x1x32_tb1x1x6x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X8X1X32_TB1X1X6X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt64x32x32_lt8x8_lw4x2_lr2x2_ta1x1x1x32_1x8x1x8_tb1x1x4x4_1x8x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X8X1X8_TB1X1X4X4_1X8X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt64x64x32_lt8x8_lw2x2_lr2x2_ta1x1x1x16_1x8x1x16_tb1x1x4x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X8X1X16_TB1X1X4X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt64x64x64_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x16x1x8_tb1x1x8x4_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X16X1X8_TB1X1X8X4_1X16X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt96x128x32_lt8x8_lw4x2_lr3x2_ta1x1x1x12_1x8x1x32_tb1x1x4x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT96X128X32_LT8X8_LW4X2_LR3X2_TA1X1X1X12_1X8X1X32_TB1X1X4X4_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x4_bx0_ex1_bt96x96x32_lt8x8_lw2x2_lr3x3_ta1x1x1x24_1x8x1x16_tb1x1x6x4_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X4_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X8X1X16_TB1X1X6X4_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt128x128x32_lt8x8_lw2x4_lr2x4_ta1x1x1x16_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt128x160x64_lt8x8_lw4x2_lr2x5_ta1x1x1x32_1x8x1x32_tb1x1x5x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt128x192x32_lt8x8_lw2x4_lr2x6_ta1x1x1x16_1x4x1x64_tb1x1x3x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt128x224x64_lt8x8_lw4x2_lr2x7_ta1x1x1x32_1x8x1x32_tb1x1x7x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt128x256x32_lt8x8_lw2x4_lr2x8_ta1x1x1x16_1x4x1x64_tb1x1x4x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt128x32x32_lt8x8_lw4x1_lr2x2_ta1x1x1x32_1x4x1x32_tb1x1x1x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt128x64x32_lt8x8_lw4x2_lr2x2_ta1x1x1x16_1x4x1x64_tb1x1x1x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt128x96x64_lt8x8_lw4x2_lr2x3_ta1x1x1x32_1x8x1x32_tb1x1x3x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt160x128x64_lt8x8_lw2x4_lr5x2_ta1x1x1x40_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt160x64x64_lt8x8_lw2x4_lr5x1_ta1x1x1x40_1x8x1x32_tb1x1x2x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt192x128x32_lt8x8_lw2x4_lr3x4_ta1x1x1x24_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt192x64x32_lt8x8_lw2x4_lr3x2_ta1x1x1x24_1x4x1x64_tb1x1x1x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt224x128x64_lt8x8_lw2x4_lr7x2_ta1x1x1x56_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt256x128x32_lt8x8_lw4x2_lr2x8_ta1x1x1x32_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt32x128x32_lt8x8_lw1x4_lr2x2_ta1x1x1x8_1x4x1x32_tb1x1x4x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt32x32x32_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x4x1x8_tb1x1x4x8_1x4x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt32x64x32_lt8x8_lw2x4_lr2x2_ta1x1x1x16_1x4x1x16_tb1x1x4x8_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt64x128x32_lt8x8_lw2x4_lr2x2_ta1x1x1x8_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt64x160x64_lt8x8_lw4x2_lr1x5_ta1x1x1x16_1x8x1x32_tb1x1x5x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt64x192x32_lt8x8_lw2x4_lr1x6_ta1x1x1x8_1x4x1x64_tb1x1x3x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt64x32x32_lt8x8_lw4x2_lr2x2_ta1x1x1x32_1x4x1x16_tb1x1x2x8_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt64x64x32_lt8x8_lw2x2_lr2x2_ta1x1x1x16_1x4x1x32_tb1x1x2x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt64x64x64_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x8x1x16_tb1x1x4x8_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt96x128x64_lt8x8_lw4x2_lr3x2_ta1x1x1x24_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex0_bt96x96x32_lt8x8_lw2x2_lr3x3_ta1x1x1x24_1x4x1x32_tb1x1x3x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt128x128x32_lt8x8_lw2x4_lr2x4_ta1x1x1x16_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt128x160x64_lt8x8_lw4x2_lr2x5_ta1x1x1x32_1x8x1x32_tb1x1x5x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt128x192x32_lt8x8_lw2x4_lr2x6_ta1x1x1x16_1x4x1x64_tb1x1x3x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt128x224x64_lt8x8_lw4x2_lr2x7_ta1x1x1x32_1x8x1x32_tb1x1x7x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt128x256x32_lt8x8_lw2x4_lr2x8_ta1x1x1x16_1x4x1x64_tb1x1x4x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt128x32x32_lt8x8_lw4x1_lr2x2_ta1x1x1x32_1x4x1x32_tb1x1x1x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt128x64x32_lt8x8_lw4x2_lr2x2_ta1x1x1x16_1x4x1x64_tb1x1x1x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt128x96x64_lt8x8_lw4x2_lr2x3_ta1x1x1x32_1x8x1x32_tb1x1x3x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt160x128x64_lt8x8_lw2x4_lr5x2_ta1x1x1x40_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt160x64x64_lt8x8_lw2x4_lr5x1_ta1x1x1x40_1x8x1x32_tb1x1x2x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt192x128x32_lt8x8_lw2x4_lr3x4_ta1x1x1x24_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt192x64x32_lt8x8_lw2x4_lr3x2_ta1x1x1x24_1x4x1x64_tb1x1x1x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt224x128x64_lt8x8_lw2x4_lr7x2_ta1x1x1x56_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt256x128x32_lt8x8_lw4x2_lr2x8_ta1x1x1x32_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt32x128x32_lt8x8_lw1x4_lr2x2_ta1x1x1x8_1x4x1x32_tb1x1x4x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt32x32x32_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x4x1x8_tb1x1x4x8_1x4x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt32x64x32_lt8x8_lw2x4_lr2x2_ta1x1x1x16_1x4x1x16_tb1x1x4x8_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt64x128x32_lt8x8_lw2x4_lr2x2_ta1x1x1x8_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt64x160x64_lt8x8_lw4x2_lr1x5_ta1x1x1x16_1x8x1x32_tb1x1x5x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt64x192x32_lt8x8_lw2x4_lr1x6_ta1x1x1x8_1x4x1x64_tb1x1x3x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt64x32x32_lt8x8_lw4x2_lr2x2_ta1x1x1x32_1x4x1x16_tb1x1x2x8_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt64x64x32_lt8x8_lw2x2_lr2x2_ta1x1x1x16_1x4x1x32_tb1x1x2x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt64x64x64_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x8x1x16_tb1x1x4x8_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt96x128x64_lt8x8_lw4x2_lr3x2_ta1x1x1x24_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_cyxkc_fp16x8_bx0_ex1_bt96x96x32_lt8x8_lw2x2_lr3x3_ta1x1x1x24_1x4x1x32_tb1x1x3x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_CYXKC_FP16X8_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt128x128x32_lt8x8_lw2x4_lr2x4_ta1x1x1x16_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt128x160x64_lt8x8_lw4x2_lr2x5_ta1x1x1x32_1x8x1x32_tb1x1x5x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt128x192x32_lt8x8_lw2x4_lr2x6_ta1x1x1x16_1x4x1x64_tb1x1x3x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt128x224x64_lt8x8_lw4x2_lr2x7_ta1x1x1x32_1x8x1x32_tb1x1x7x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt128x256x32_lt8x8_lw2x4_lr2x8_ta1x1x1x16_1x4x1x64_tb1x1x4x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt128x32x32_lt8x8_lw4x1_lr2x2_ta1x1x1x32_1x4x1x32_tb1x1x1x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt128x64x32_lt8x8_lw4x2_lr2x2_ta1x1x1x16_1x4x1x64_tb1x1x1x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt128x96x64_lt8x8_lw4x2_lr2x3_ta1x1x1x32_1x8x1x32_tb1x1x3x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt160x128x64_lt8x8_lw2x4_lr5x2_ta1x1x1x40_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt160x64x64_lt8x8_lw2x4_lr5x1_ta1x1x1x40_1x8x1x32_tb1x1x2x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt192x128x32_lt8x8_lw2x4_lr3x4_ta1x1x1x24_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt192x64x32_lt8x8_lw2x4_lr3x2_ta1x1x1x24_1x4x1x64_tb1x1x1x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt224x128x64_lt8x8_lw2x4_lr7x2_ta1x1x1x56_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt256x128x32_lt8x8_lw4x2_lr2x8_ta1x1x1x32_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt32x128x32_lt8x8_lw1x4_lr2x2_ta1x1x1x8_1x4x1x32_tb1x1x4x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt32x32x32_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x4x1x8_tb1x1x4x8_1x4x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt32x64x32_lt8x8_lw2x4_lr2x2_ta1x1x1x16_1x4x1x16_tb1x1x4x8_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt64x128x32_lt8x8_lw2x4_lr2x2_ta1x1x1x8_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt64x160x64_lt8x8_lw4x2_lr1x5_ta1x1x1x16_1x8x1x32_tb1x1x5x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt64x192x32_lt8x8_lw2x4_lr1x6_ta1x1x1x8_1x4x1x64_tb1x1x3x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt64x32x32_lt8x8_lw4x2_lr2x2_ta1x1x1x32_1x4x1x16_tb1x1x2x8_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt64x64x32_lt8x8_lw2x2_lr2x2_ta1x1x1x16_1x4x1x32_tb1x1x2x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt64x64x64_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x8x1x16_tb1x1x4x8_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt96x128x64_lt8x8_lw4x2_lr3x2_ta1x1x1x24_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex0_bt96x96x32_lt8x8_lw2x2_lr3x3_ta1x1x1x24_1x4x1x32_tb1x1x3x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX0_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt128x128x32_lt8x8_lw2x4_lr2x4_ta1x1x1x16_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X128X32_LT8X8_LW2X4_LR2X4_TA1X1X1X16_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt128x160x64_lt8x8_lw4x2_lr2x5_ta1x1x1x32_1x8x1x32_tb1x1x5x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X160X64_LT8X8_LW4X2_LR2X5_TA1X1X1X32_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt128x192x32_lt8x8_lw2x4_lr2x6_ta1x1x1x16_1x4x1x64_tb1x1x3x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X192X32_LT8X8_LW2X4_LR2X6_TA1X1X1X16_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt128x224x64_lt8x8_lw4x2_lr2x7_ta1x1x1x32_1x8x1x32_tb1x1x7x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X224X64_LT8X8_LW4X2_LR2X7_TA1X1X1X32_1X8X1X32_TB1X1X7X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt128x256x32_lt8x8_lw2x4_lr2x8_ta1x1x1x16_1x4x1x64_tb1x1x4x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X256X32_LT8X8_LW2X4_LR2X8_TA1X1X1X16_1X4X1X64_TB1X1X4X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt128x32x32_lt8x8_lw4x1_lr2x2_ta1x1x1x32_1x4x1x32_tb1x1x1x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X32X32_LT8X8_LW4X1_LR2X2_TA1X1X1X32_1X4X1X32_TB1X1X1X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt128x64x32_lt8x8_lw4x2_lr2x2_ta1x1x1x16_1x4x1x64_tb1x1x1x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X64X32_LT8X8_LW4X2_LR2X2_TA1X1X1X16_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt128x96x64_lt8x8_lw4x2_lr2x3_ta1x1x1x32_1x8x1x32_tb1x1x3x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT128X96X64_LT8X8_LW4X2_LR2X3_TA1X1X1X32_1X8X1X32_TB1X1X3X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt160x128x64_lt8x8_lw2x4_lr5x2_ta1x1x1x40_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT160X128X64_LT8X8_LW2X4_LR5X2_TA1X1X1X40_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt160x64x64_lt8x8_lw2x4_lr5x1_ta1x1x1x40_1x8x1x32_tb1x1x2x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT160X64X64_LT8X8_LW2X4_LR5X1_TA1X1X1X40_1X8X1X32_TB1X1X2X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt192x128x32_lt8x8_lw2x4_lr3x4_ta1x1x1x24_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT192X128X32_LT8X8_LW2X4_LR3X4_TA1X1X1X24_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt192x64x32_lt8x8_lw2x4_lr3x2_ta1x1x1x24_1x4x1x64_tb1x1x1x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT192X64X32_LT8X8_LW2X4_LR3X2_TA1X1X1X24_1X4X1X64_TB1X1X1X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt224x128x64_lt8x8_lw2x4_lr7x2_ta1x1x1x56_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT224X128X64_LT8X8_LW2X4_LR7X2_TA1X1X1X56_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt256x128x32_lt8x8_lw4x2_lr2x8_ta1x1x1x32_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT256X128X32_LT8X8_LW4X2_LR2X8_TA1X1X1X32_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt32x128x32_lt8x8_lw1x4_lr2x2_ta1x1x1x8_1x4x1x32_tb1x1x4x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X128X32_LT8X8_LW1X4_LR2X2_TA1X1X1X8_1X4X1X32_TB1X1X4X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt32x32x32_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x4x1x8_tb1x1x4x8_1x4x1x8.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X32X32_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X4X1X8_TB1X1X4X8_1X4X1X8_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt32x64x32_lt8x8_lw2x4_lr2x2_ta1x1x1x16_1x4x1x16_tb1x1x4x8_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT32X64X32_LT8X8_LW2X4_LR2X2_TA1X1X1X16_1X4X1X16_TB1X1X4X8_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt64x128x32_lt8x8_lw2x4_lr2x2_ta1x1x1x8_1x4x1x64_tb1x1x2x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X128X32_LT8X8_LW2X4_LR2X2_TA1X1X1X8_1X4X1X64_TB1X1X2X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt64x160x64_lt8x8_lw4x2_lr1x5_ta1x1x1x16_1x8x1x32_tb1x1x5x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X160X64_LT8X8_LW4X2_LR1X5_TA1X1X1X16_1X8X1X32_TB1X1X5X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt64x192x32_lt8x8_lw2x4_lr1x6_ta1x1x1x8_1x4x1x64_tb1x1x3x8_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X192X32_LT8X8_LW2X4_LR1X6_TA1X1X1X8_1X4X1X64_TB1X1X3X8_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt64x32x32_lt8x8_lw4x2_lr2x2_ta1x1x1x32_1x4x1x16_tb1x1x2x8_1x4x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X32X32_LT8X8_LW4X2_LR2X2_TA1X1X1X32_1X4X1X16_TB1X1X2X8_1X4X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt64x64x32_lt8x8_lw2x2_lr2x2_ta1x1x1x16_1x4x1x32_tb1x1x2x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X64X32_LT8X8_LW2X2_LR2X2_TA1X1X1X16_1X4X1X32_TB1X1X2X8_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt64x64x64_lt8x8_lw2x2_lr2x2_ta1x1x1x32_1x8x1x16_tb1x1x4x8_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT64X64X64_LT8X8_LW2X2_LR2X2_TA1X1X1X32_1X8X1X16_TB1X1X4X8_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt96x128x64_lt8x8_lw4x2_lr3x2_ta1x1x1x24_1x8x1x32_tb1x1x4x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT96X128X64_LT8X8_LW4X2_LR3X2_TA1X1X1X24_1X8X1X32_TB1X1X4X8_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcn2_nchwc_kcyxc_fp16x8_bx0_ex1_bt96x96x32_lt8x8_lw2x2_lr3x3_ta1x1x1x24_1x4x1x32_tb1x1x3x8_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCN2_NCHWC_KCYXC_FP16X8_BX0_EX1_BT96X96X32_LT8X8_LW2X2_LR3X3_TA1X1X1X24_1X4X1X32_TB1X1X3X8_1X4X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x16x16_wt32x8x4_ws2x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x16x16_wt32x8x4_ws2x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt16x128x16_wt8x32x4_ws1x2_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt16x128x16_wt8x32x4_ws1x2_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x1x2_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x1x2_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x1x1x16_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x1x1x16_1x16x1x4_tb1x1x1x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx16_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX16_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx1_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x1x1x32_1x32x1x8_tb1x1x1x16_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X1X16_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X1X16_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx1_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX1_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x16x32_wt32x8x4_ws2x1_wr1x1_ta1x2x1x8_1x16x1x16_tb1x2x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X2X1X8_1X16X1X16_TB1X2X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X2X1X8_1X16X1X16_TB1X2X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x16x32_wt32x8x4_ws2x1_wr1x1_ta1x2x1x8_1x16x1x16_tb1x2x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X2X1X8_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X2X1X8_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x2x1x4_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x2x1x4_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X2X1X4_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x32x32_wt16x16x16_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x32x32_wt16x16x16_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt16x128x32_wt8x32x4_ws1x2_wr1x1_ta1x2x1x1_1x16x1x16_tb1x2x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt16x128x32_wt8x32x4_ws1x2_wr1x1_ta1x2x1x1_1x16x1x16_tb1x2x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt16x256x32_wt4x64x4_ws1x1_wr2x2_ta1x2x1x1_1x16x1x16_tb1x2x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X2X1X1_1X16X1X16_TB1X2X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X2X1X1_1X16X1X16_TB1X2X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt16x256x32_wt4x64x4_ws1x1_wr2x2_ta1x2x1x1_1x16x1x16_tb1x2x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X2X1X1_1X16X1X16_TB1X2X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X2X1X1_1X16X1X16_TB1X2X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt16x64x32_wt4x64x4_ws1x1_wr1x1_ta1x2x1x1_1x16x1x16_tb1x2x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt16x64x32_wt4x64x4_ws1x1_wr1x1_ta1x2x1x1_1x16x1x16_tb1x2x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X16_TB1X2X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x16x32_wt64x4x4_ws1x1_wr2x2_ta1x2x1x16_1x16x1x16_tb1x2x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X2X1X16_1X16X1X16_TB1X2X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X2X1X16_1X16X1X16_TB1X2X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x16x32_wt64x4x4_ws1x1_wr2x2_ta1x2x1x16_1x16x1x16_tb1x2x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X2X1X16_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X2X1X16_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x2x1x8_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X2X1X8_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x32x32_wt64x4x4_ws1x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x32x32_wt64x4x4_ws1x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x128x32_wt16x16x16_ws1x1_wr2x2_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x128x32_wt16x16x16_ws1x1_wr2x2_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x2x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X8X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x2x1x1_1x8x1x32_tb1x2x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X2X1X1_1X8X1X32_TB1X2X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x256x32_wt4x64x4_ws2x1_wr2x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x256x32_wt4x64x4_ws2x1_wr2x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x2x1x1_1x8x1x32_tb1x2x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X2X1X1_1X8X1X32_TB1X2X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x64x32_wt8x32x4_ws2x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt32x64x32_wt8x32x4_ws2x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt4x64x32_wt4x64x4_ws1x1_wr1x1_ta1x2x1x1_1x16x1x4_tb1x2x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X4_TB1X2X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X4_TB1X2X16X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt4x64x32_wt4x64x4_ws1x1_wr1x1_ta1x2x1x1_1x16x1x4_tb1x2x16x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X4_TB1X2X16X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X2X1X1_1X16X1X4_TB1X2X16X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x128x32_wt16x16x16_ws1x2_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x128x32_wt16x16x16_ws1x2_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x16x32_wt64x4x4_ws1x1_wr1x1_ta1x2x1x4_1x16x1x16_tb1x2x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x16x32_wt64x4x4_ws1x1_wr1x1_ta1x2x1x4_1x16x1x16_tb1x2x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X4_1X16X1X16_TB1X2X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x2x1x2_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X2X1X2_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x32x32_wt32x8x4_ws1x2_wr1x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x32x32_wt32x8x4_ws1x2_wr1x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x4x32_wt64x4x4_ws1x1_wr1x1_ta1x2x1x16_1x16x1x4_tb1x2x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X16_1X16X1X4_TB1X2X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X16_1X16X1X4_TB1X2X1X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x4x32_wt64x4x4_ws1x1_wr1x1_ta1x2x1x16_1x16x1x4_tb1x2x1x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X16_1X16X1X4_TB1X2X1X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X2X1X16_1X16X1X4_TB1X2X1X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex0_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX0_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x16x16_wt32x8x4_ws2x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x16x16_wt32x8x4_ws2x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X16_WT32X8X4_WS2X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x16x32_wt32x8x4_ws2x1_wr1x1_ta1x1x1x16_1x32x1x8_tb1x1x2x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X1X1X16_1X32X1X8_TB1X1X2X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X1X1X16_1X32X1X8_TB1X1X2X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x16x32_wt32x8x4_ws2x1_wr1x1_ta1x1x1x16_1x32x1x8_tb1x1x2x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X1X1X16_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X16X32_WT32X8X4_WS2X1_WR1X1_TA1X1X1X16_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x32x32_wt16x16x16_ws1x1_wr2x2_ta1x1x1x16_1x32x1x8_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x32x32_wt16x16x16_ws1x1_wr2x2_ta1x1x1x16_1x32x1x8_tb1x1x4x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X32X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x64x16_wt32x8x4_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X16_WT32X8X4_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x1x1x16_1x32x1x8_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt128x64x32_wt16x16x16_ws2x1_wr2x2_ta1x1x1x16_1x32x1x8_tb1x1x8x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT128X64X32_WT16X16X16_WS2X1_WR2X2_TA1X1X1X16_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x128x16_wt8x32x4_ws1x2_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x128x16_wt8x32x4_ws1x2_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X16_WT8X32X4_WS1X2_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x128x32_wt8x32x4_ws1x2_wr1x1_ta1x1x1x2_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x128x32_wt8x32x4_ws1x2_wr1x1_ta1x1x1x2_1x32x1x8_tb1x1x16x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X128X32_WT8X32X4_WS1X2_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x256x16_wt4x64x4_ws1x1_wr2x2_ta1x1x1x1_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X16_WT4X64X4_WS1X1_WR2X2_TA1X1X1X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x256x32_wt4x64x4_ws1x1_wr2x2_ta1x1x1x2_1x32x1x8_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X1X1X2_1X32X1X8_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X1X1X2_1X32X1X8_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x256x32_wt4x64x4_ws1x1_wr2x2_ta1x1x1x2_1x32x1x8_tb1x1x32x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X1X1X2_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X256X32_WT4X64X4_WS1X1_WR2X2_TA1X1X1X2_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x64x32_wt4x64x4_ws1x1_wr1x1_ta1x1x1x2_1x32x1x8_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt16x64x32_wt4x64x4_ws1x1_wr1x1_ta1x1x1x2_1x32x1x8_tb1x1x8x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT16X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x16x16_wt64x4x4_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X16_WT64X4X4_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x16x32_wt64x4x4_ws1x1_wr2x2_ta1x1x1x32_1x32x1x8_tb1x1x2x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X2X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X2X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x16x32_wt64x4x4_ws1x1_wr2x2_ta1x1x1x32_1x32x1x8_tb1x1x2x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X16X32_WT64X4X4_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x32x16_wt64x4x4_ws1x2_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X16_WT64X4X4_WS1X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x32x32_wt64x4x4_ws1x2_wr2x2_ta1x1x1x32_1x32x1x8_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x32x32_wt64x4x4_ws1x2_wr2x2_ta1x1x1x32_1x32x1x8_tb1x1x4x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X32X32_WT64X4X4_WS1X2_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x1x1x32_1x32x1x8_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x1x1x32_1x32x1x8_tb1x1x8x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X32_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x128x16_wt16x64x4_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X16_WT16X64X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x128x32_wt16x16x16_ws1x1_wr2x2_ta1x1x1x4_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x128x32_wt16x16x16_ws1x1_wr2x2_ta1x1x1x4_1x32x1x8_tb1x1x16x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X128X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x1x2_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x256x16_wt4x64x4_ws2x1_wr2x2_ta1x1x1x2_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X16_WT4X64X4_WS2X1_WR2X2_TA1X1X1X2_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x256x32_wt4x64x4_ws2x1_wr2x2_ta1x1x1x4_1x32x1x8_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x256x32_wt4x64x4_ws2x1_wr2x2_ta1x1x1x4_1x32x1x8_tb1x1x32x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X256X32_WT4X64X4_WS2X1_WR2X2_TA1X1X1X4_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x32x16_wt16x16x4_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X16_WT16X16X4_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x32x32_wt16x16x16_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x4x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X32X32_WT16X16X16_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x64x16_wt8x32x4_ws2x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X16_WT8X32X4_WS2X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x64x32_wt8x32x4_ws2x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt32x64x32_wt8x32x4_ws2x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x8x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT32X64X32_WT8X32X4_WS2X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt4x64x16_wt4x64x4_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X16_WT4X64X4_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt4x64x32_wt4x64x4_ws1x1_wr1x1_ta1x1x1x2_1x32x1x2_tb1x1x32x1_1x32x1x2.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X2_TB1X1X32X1_1X32X1X2, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X2_TB1X1X32X1_1X32X1X2_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt4x64x32_wt4x64x4_ws1x1_wr1x1_ta1x1x1x2_1x32x1x2_tb1x1x32x1_1x32x1x2_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X2_TB1X1X32X1_1X32X1X2_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT4X64X32_WT4X64X4_WS1X1_WR1X1_TA1X1X1X2_1X32X1X2_TB1X1X32X1_1X32X1X2_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x128x16_wt8x32x4_ws2x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X16_WT8X32X4_WS2X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt16x16x16_ws1x2_wr2x2_ta1x1x1x8_1x32x1x8_tb1x1x16x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X16X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X16X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x128x32_wt16x16x16_ws1x2_wr2x2_ta1x1x1x8_1x32x1x8_tb1x1x16x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X128X32_WT16X16X16_WS1X2_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X16X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x16x16_wt64x4x4_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x16x32_wt64x4x4_ws1x1_wr1x1_ta1x1x1x8_1x32x1x8_tb1x1x2x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X2X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X2X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x16x32_wt64x4x4_ws1x1_wr1x1_ta1x1x1x8_1x32x1x8_tb1x1x2x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X16X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X2X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x1x1x8_1x32x1x8_tb1x1x32x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X32X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X32X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x1x1x8_1x32x1x8_tb1x1x32x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X32X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x32x16_wt32x8x4_ws1x2_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X16_WT32X8X4_WS1X2_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x32x32_wt32x8x4_ws1x2_wr1x1_ta1x1x1x8_1x32x1x8_tb1x1x4x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X4X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X4X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x32x32_wt32x8x4_ws1x2_wr1x1_ta1x1x1x8_1x32x1x8_tb1x1x4x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X32X32_WT32X8X4_WS1X2_WR1X1_TA1X1X1X8_1X32X1X8_TB1X1X4X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x1x1x16_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x4x16_wt64x4x4_ws1x1_wr1x1_ta1x1x1x16_1x16x1x4_tb1x1x1x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X16_WT64X4X4_WS1X1_WR1X1_TA1X1X1X16_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x4x32_wt64x4x4_ws1x1_wr1x1_ta1x1x1x32_1x32x1x2_tb1x1x2x1_1x32x1x2.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X32_1X32X1X2_TB1X1X2X1_1X32X1X2, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X32_1X32X1X2_TB1X1X2X1_1X32X1X2_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x4x32_wt64x4x4_ws1x1_wr1x1_ta1x1x1x32_1x32x1x2_tb1x1x2x1_1x32x1x2_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X32_1X32X1X2_TB1X1X2X1_1X32X1X2_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X4X32_WT64X4X4_WS1X1_WR1X1_TA1X1X1X32_1X32X1X2_TB1X1X2X1_1X32X1X2_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x1x1x8_1x32x1x8_tb1x1x8x1_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X8X1_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X8X1_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx4_ex1_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x1x1x8_1x32x1x8_tb1x1x8x1_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX4_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X1X1X8_1X32X1X8_TB1X1X8X1_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx8_ex1_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx8_ex1_bt32x32x8_wt16x16x4_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X32X8_WT16X16X4_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx8_ex1_bt32x64x8_wt8x32x4_ws2x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT32X64X8_WT8X32X4_WS2X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx8_ex1_bt64x32x8_wt32x8x4_ws1x2_wr1x1_ta1x1x1x2_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X1X2_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT64X32X8_WT32X8X4_WS1X2_WR1X1_TA1X1X1X2_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp16_bx8_ex1_bt64x64x32_wt16x16x16_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP16_BX8_EX1_BT64X64X32_WT16X16X16_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x2_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x2_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x64x4_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt256x64x4_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x4_wt16x16x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x4_wt16x16x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x4x1_1x16x1x8_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x1_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x64x32_wt32x32x8_ws1x1_wr1x1_ta1x8x1x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex0_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nhwc_fp32_bx0_ex1_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x2_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x2_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x4_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x4_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x4_wt16x16x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x4_wt16x16x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x4x1_1x16x1x8_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x4x1_1x16x1x8_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x1_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x32_wt32x32x8_ws1x1_wr1x1_ta1x8x1x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_bf16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x32_wt32x32x8_ws1x1_wr1x1_ta1x8x1x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex0_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx2_nhwc_fp32_bx0_ex1_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX2_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x8_wt64x16x4_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X8_WT64X16X4_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x8_wt32x32x4_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X8_WT32X32X4_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x8_wt64x32x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X8_WT64X32X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x16_wt64x16x4_ws1x1_wr2x1_ta1x8x2x1_1x2x1x128_tb1x2x1x1_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X16_WT64X16X4_WS1X1_WR2X1_TA1X8X2X1_1X2X1X128_TB1X2X1X1_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x8x4x1_1x4x1x64_tb1x2x1x2_1x16x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X8X4X1_1X4X1X64_TB1X2X1X2_1X16X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x2x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X2X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x4x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X4X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x1x4_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X1X4_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x1x2_1x4x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X1X2_1X4X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x1x2_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X1X2_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x1x4_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X1X4_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x4x2x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X4X2X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x4x1x2_1x8x1x16_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X4X1X2_1X8X1X16_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x1x2_1x8x1x32_mh_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X1X2_1X8X1X32_MH_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x8_wt16x16x4_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X8_WT16X16X4_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_VS1_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x2_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x2_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X2_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr2x1_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR2X1_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x4_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x4_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x16x16_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x4x1x32_tb1x2x1x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X16_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X4X1X32_TB1X2X1X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x2x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X2X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_mh_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_MH_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x4_wt16x16x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x4_wt16x16x1_ws1x1_wr2x2_ta1x1x1x1_1x4x1x64_tb1x1x1x1_1x4x1x64_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X4_WT16X16X1_WS1X1_WR2X2_TA1X1X1X1_1X4X1X64_TB1X1X1X1_1X4X1X64_MH_ME_GKGS_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_SIZE } },
    { "igemm_bwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_mh_me_gkgs.s", { MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS, MIOPEN_KERNEL_IGEMM_BWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_MH_ME_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x4x1_1x16x1x8_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x4_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X4_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x8_wt32x32x4_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X8_WT32X32X4_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x8x2x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X8X2X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x32x32_wt64x16x4_ws1x1_wr1x1_ta1x4x4x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X32X32_WT64X16X4_WS1X1_WR1X1_TA1X4X4X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x16_wt32x32x4_ws1x1_wr2x1_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X16_WT32X32X4_WS1X1_WR2X1_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x8x1x1_1x4x1x64_pta_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X8X1X1_1X4X1X64_PTA_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x8x2x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X8X2X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x16_wt64x32x4_ws1x1_wr2x2_ta1x8x2x1_1x2x1x128_tb1x8x1x1_1x2x1x128_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT64X32X4_WS1X1_WR2X2_TA1X8X2X1_1X2X1X128_TB1X8X1X1_1X2X1X128_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x8x1_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X8X1_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x8_wt64x16x4_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X8_WT64X16X4_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x16_wt64x32x4_ws1x1_wr1x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT64X32X4_WS1X1_WR1X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x8x4x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X8X4X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x8_wt64x16x4_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X8_WT64X16X4_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x128x32_wt16x64x4_ws1x1_wr1x1_ta1x4x1x1_1x8x1x32_tb1x4x4x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X128X32_WT16X64X4_WS1X1_WR1X1_TA1X4X1X1_1X8X1X32_TB1X4X4X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x8x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X8X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt32x64x32_wt16x64x4_ws1x1_wr1x1_ta1x8x1x1_1x4x1x32_tb1x8x2x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT32X64X32_WT16X64X4_WS1X1_WR1X1_TA1X8X1X1_1X4X1X32_TB1X8X2X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x8x1x1_1x4x1x64_tb1x8x2x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X8X1X1_1X4X1X64_TB1X8X2X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x8x1x1_1x4x1x64_tb1x8x4x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X8X1X1_1X4X1X64_TB1X8X4X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x16_wt64x16x4_ws1x1_wr1x1_ta1x1x8x1_1x16x1x8_tb1x1x4x1_1x16x1x8_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X16_WT64X16X4_WS1X1_WR1X1_TA1X1X8X1_1X16X1X8_TB1X1X4X1_1X16X1X8_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x32_wt64x16x4_ws1x1_wr1x1_ta1x8x2x1_1x4x1x32_tb1x8x1x1_1x4x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT64X16X4_WS1X1_WR1X1_TA1X8X2X1_1X4X1X32_TB1X8X1X1_1X4X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x16_wt16x16x4_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT16X16X4_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt16x16x16_ws1x1_wr2x2_ta1x8x2x1_1x8x1x32_tb1x8x2x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT16X16X16_WS1X1_WR2X2_TA1X8X2X1_1X8X1X32_TB1X8X2X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex0_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x4_wt32x32x1_ws1x1_wr2x2_ta1x1x2x1_1x4x1x64_tb1x1x2x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X4_WT32X32X1_WS1X1_WR2X2_TA1X1X2X1_1X4X1X64_TB1X1X2X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x8_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x2x1x128_tb1x4x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X8_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr2x1_ta1x4x4x1_1x4x1x32_tb1x4x1x1_1x4x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR2X1_TA1X4X4X1_1X4X1X32_TB1X4X1X1_1X4X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x32_wt32x32x2_ws1x1_wr2x1_ta1x4x8x1_1x8x1x16_tb1x4x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X32_WT32X32X2_WS1X1_WR2X1_TA1X4X8X1_1X8X1X16_TB1X4X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x4_wt64x32x1_ws1x1_wr1x1_ta1x1x4x1_1x4x1x32_tb1x1x1x1_1x4x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X4_WT64X32X1_WS1X1_WR1X1_TA1X1X4X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x8_wt32x32x2_ws1x1_wr1x1_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X8_WT32X32X2_WS1X1_WR1X1_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr1x2_ta1x8x1x1_1x2x4x32_tb1x4x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR1X2_TA1X8X1X1_1X2X4X32_TB1X4X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x32_wt32x32x2_ws1x1_wr1x2_ta1x16x1x1_1x2x4x32_tb1x4x2x1_1x8x1x32_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X32_WT32X32X2_WS1X1_WR1X2_TA1X16X1X1_1X2X4X32_TB1X4X2X1_1X8X1X32_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x4_wt64x32x1_ws1x1_wr1x1_ta1x1x2x1_1x4x1x64_tb1x1x1x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X4_WT64X32X1_WS1X1_WR1X1_TA1X1X2X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x8_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x2x4x32_tb1x2x1x1_1x4x1x64_pta_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X8_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X2X4X32_TB1X2X1X1_1X4X1X64_PTA_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt16x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x16_tb1x4x4x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT16X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X16_TB1X4X4X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x2x8x1_1x8x1x32_tb1x2x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X2X8X1_1X8X1X32_TB1X2X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x4_wt64x32x1_ws1x1_wr2x1_ta1x1x8x1_1x4x1x32_tb1x1x1x1_1x4x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X4_WT64X32X1_WS1X1_WR2X1_TA1X1X8X1_1X4X1X32_TB1X1X1X1_1X4X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x8_wt32x32x2_ws1x1_wr2x1_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X8_WT32X32X2_WS1X1_WR2X1_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_me.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_ME_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt32x64x32_wt16x16x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X32_WT16X16X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x4x1x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X4X1X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x16x32_wt16x16x4_ws1x1_wr2x1_ta1x4x4x1_1x8x1x16_tb1x4x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X16X32_WT16X16X4_WS1X1_WR2X1_TA1X4X4X1_1X8X1X16_TB1X4X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x4x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X4X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x32x32_wt16x16x4_ws1x1_wr2x1_ta1x4x2x1_1x8x1x32_tb1x4x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X32_WT16X16X4_WS1X1_WR2X1_TA1X4X2X1_1X8X1X32_TB1X4X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_SIZE } },
    { "igemm_fwd_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x32_wt16x16x4_ws1x1_wr2x2_ta1x4x2x1_1x8x1x32_tb1x4x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_FWD_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X32_WT16X16X4_WS1X1_WR2X2_TA1X4X2X1_1X8X1X32_TB1X4X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x32_wt32x32x8_ws1x1_wr1x1_ta1x8x1x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_bf16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_BF16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex0_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX0_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x128x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X128X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x16_wt32x32x8_ws1x2_wr2x2_ta1x4x1x2_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X16_WT32X32X8_WS1X2_WR2X2_TA1X4X1X2_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x256x32_wt32x32x8_ws1x2_wr2x2_ta1x4x1x4_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X256X32_WT32X32X8_WS1X2_WR2X2_TA1X4X1X4_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt128x64x32_wt32x32x8_ws1x1_wr1x2_ta1x4x1x4_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT128X64X32_WT32X32X8_WS1X1_WR1X2_TA1X4X1X4_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x16_wt32x32x8_ws2x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X16_WT32X32X8_WS2X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x128x32_wt32x32x8_ws2x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X128X32_WT32X32X8_WS2X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x256x32_wt32x32x8_ws2x2_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X256X32_WT32X32X8_WS2X2_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x32x32_wt64x16x4_ws1x1_wr2x1_ta1x4x1x8_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X32X32_WT64X16X4_WS1X1_WR2X1_TA1X4X1X8_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x4_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X4_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt256x64x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x8_1x8x1x32_tb1x4x1x2_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT256X64X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X8_1X8X1X32_TB1X4X1X2_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt32x256x32_wt16x64x4_ws1x1_wr1x2_ta1x4x1x1_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT32X256X32_WT16X64X4_WS1X1_WR1X2_TA1X4X1X1_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x16_wt32x32x8_ws1x1_wr2x1_ta1x4x1x1_1x4x1x64_tb1x4x1x2_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X16_WT32X32X8_WS1X1_WR2X1_TA1X4X1X1_1X4X1X64_TB1X4X1X2_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x128x32_wt32x32x8_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x4_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X128X32_WT32X32X8_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X4_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x16_wt32x32x8_ws1x1_wr2x2_ta1x4x1x1_1x4x1x64_tb1x4x1x4_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X16_WT32X32X8_WS1X1_WR2X2_TA1X4X1X1_1X4X1X64_TB1X4X1X4_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x256x32_wt32x32x8_ws1x1_wr2x2_ta1x4x1x2_1x8x1x32_tb1x4x1x8_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X256X32_WT32X32X8_WS1X1_WR2X2_TA1X4X1X2_1X8X1X32_TB1X4X1X8_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x32x32_wt16x16x16_ws1x1_wr2x1_ta1x4x1x2_1x8x1x32_tb1x4x1x1_1x8x1x32_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X32X32_WT16X16X16_WS1X1_WR2X1_TA1X4X1X2_1X8X1X32_TB1X4X1X1_1X8X1X32_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x16_wt32x32x8_ws1x1_wr1x1_ta1x4x1x1_1x4x1x64_tb1x4x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X16_WT32X32X8_WS1X1_WR1X1_TA1X4X1X1_1X4X1X64_TB1X4X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x32_wt32x32x8_ws1x1_wr1x1_ta1x8x1x1_1x4x1x64_tb1x8x1x1_1x4x1x64_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X32_WT32X32X8_WS1X1_WR1X1_TA1X8X1X1_1X4X1X64_TB1X8X1X1_1X4X1X64_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp16_bx0_ex1_bt64x64x64_wt32x32x8_ws1x1_wr1x1_ta1x4x1x4_1x16x1x16_tb1x4x1x4_1x16x1x16_vs1_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP16_BX0_EX1_BT64X64X64_WT32X32X8_WS1X1_WR1X1_TA1X4X1X4_1X16X1X16_TB1X4X1X4_1X16X1X16_VS1_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt256x256x16_wt32x32x2_ws2x2_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt256x256x16_wt32x32x2_ws2x2_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex0_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX0_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt128x128x16_wt32x32x2_ws1x2_wr1x2_ta1x1x1x8_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X128X16_WT32X32X2_WS1X2_WR1X2_TA1X1X1X8_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt128x256x16_wt32x32x2_ws1x2_wr2x2_ta1x1x1x8_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X256X16_WT32X32X2_WS1X2_WR2X2_TA1X1X1X8_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt128x32x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x8_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X32X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X8_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt128x64x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x8_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT128X64X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X8_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt256x128x16_wt32x32x2_ws2x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X128X16_WT32X32X2_WS2X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt256x256x16_wt32x32x2_ws2x2_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt256x256x16_wt32x32x2_ws2x2_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X256X16_WT32X32X2_WS2X2_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt256x32x16_wt32x32x2_ws1x1_wr2x1_ta1x1x1x16_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X32X16_WT32X32X2_WS1X1_WR2X1_TA1X1X1X16_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt256x64x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x16_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT256X64X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X16_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt32x128x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x2_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X128X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X2_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt32x256x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X256X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt32x32x32_wt16x16x4_ws1x1_wr1x1_ta1x1x1x4_1x32x1x8_tb1x1x1x4_1x32x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X32X32_WT16X16X4_WS1X1_WR1X1_TA1X1X1X4_1X32X1X8_TB1X1X1X4_1X32X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt32x64x16_wt16x16x4_ws1x1_wr1x2_ta1x1x1x2_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT32X64X16_WT16X16X4_WS1X1_WR1X2_TA1X1X1X2_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt64x128x16_wt32x32x2_ws1x1_wr1x2_ta1x1x1x4_1x16x1x16_tb1x1x1x8_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X128X16_WT32X32X2_WS1X1_WR1X2_TA1X1X1X4_1X16X1X16_TB1X1X1X8_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt64x256x16_wt32x32x2_ws1x1_wr2x2_ta1x1x1x4_1x16x1x16_tb1x1x1x16_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X256X16_WT32X32X2_WS1X1_WR2X2_TA1X1X1X4_1X16X1X16_TB1X1X1X16_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt64x32x16_wt16x16x4_ws1x1_wr2x1_ta1x1x1x4_1x16x1x16_tb1x1x1x2_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X32X16_WT16X16X4_WS1X1_WR2X1_TA1X1X1X4_1X16X1X16_TB1X1X1X2_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx3_nhwc_fp32_bx0_ex1_bt64x64x16_wt32x32x2_ws1x1_wr1x1_ta1x1x1x4_1x16x1x16_tb1x1x1x4_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX3_NHWC_FP32_BX0_EX1_BT64X64X16_WT32X32X2_WS1X1_WR1X1_TA1X1X1X4_1X16X1X16_TB1X1X1X4_1X16X1X16_GKGS_SIZE } },
    { "igemm_v4r1_dynamic.s", { MIOPEN_KERNEL_IGEMM_V4R1_DYNAMIC, MIOPEN_KERNEL_IGEMM_V4R1_DYNAMIC_SIZE } },
    { "igemm_v4r1_wrw_dynamic.s", { MIOPEN_KERNEL_IGEMM_V4R1_WRW_DYNAMIC, MIOPEN_KERNEL_IGEMM_V4R1_WRW_DYNAMIC_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx16_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx16_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx16_ex1_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx16_ex1_bt64x4x16_wt64x4x1_ws1x1_wr1x1_ta1x1x16x1_1x16x1x4_tb1x1x1x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX16_EX1_BT64X4X16_WT64X4X1_WS1X1_WR1X1_TA1X1X16X1_1X16X1X4_TB1X1X1X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt16x32x8_wt8x32x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt16x32x8_wt8x32x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt32x32x8_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt32x32x8_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx1_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX1_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x4x2x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X4X2X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x2x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x2x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X2X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x4x2x1_1x2x1x128_tb1x4x1x1_1x2x1x128_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X4X2X1_1X2X1X128_TB1X4X1X1_1X2X1X128_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex0_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x4x4x1_1x4x1x64_tb1x4x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX0_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X4X4X1_1X4X1X64_TB1X4X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x128x16_wt32x32x1_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X16_WT32X32X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x128x8_wt32x32x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X128X8_WT32X32X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x32x16_wt32x8x1_ws1x1_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X16_WT32X8X1_WS1X1_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x32x8_wt32x8x1_ws1x1_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X32X8_WT32X8X1_WS1X1_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x64x16_wt32x8x1_ws1x2_wr2x2_ta1x1x8x1_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X16_WT32X8X1_WS1X2_WR2X2_TA1X1X8X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt128x64x8_wt32x8x1_ws1x2_wr2x2_ta1x1x4x1_1x8x1x32_tb1x1x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT128X64X8_WT32X8X1_WS1X2_WR2X2_TA1X1X4X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt16x32x16_wt8x32x1_ws1x1_wr1x1_ta1x1x2x1_1x16x1x8_tb1x1x4x1_1x16x1x8_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X16_WT8X32X1_WS1X1_WR1X1_TA1X1X2X1_1X16X1X8_TB1X1X4X1_1X16X1X8_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt16x32x8_wt8x32x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt16x32x8_wt8x32x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x128x16_wt64x32x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X16_WT64X32X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x128x8_wt64x32x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X128X8_WT64X32X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x32x16_wt64x4x1_ws1x2_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X16_WT64X4X1_WS1X2_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x32x8_wt64x4x1_ws1x2_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X32X8_WT64X4X1_WS1X2_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x64x16_wt64x16x1_ws1x1_wr2x2_ta1x1x16x1_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X16_WT64X16X1_WS1X1_WR2X2_TA1X1X16X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x64x4_wt64x16x1_ws1x1_wr2x2_ta1x1x4x1_1x4x1x64_tb1x1x1x1_1x4x1x64_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X4_WT64X16X1_WS1X1_WR2X2_TA1X1X4X1_1X4X1X64_TB1X1X1X1_1X4X1X64_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt256x64x8_wt64x16x1_ws1x1_wr2x2_ta1x1x8x1_1x8x1x32_tb1x1x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT256X64X8_WT64X16X1_WS1X1_WR2X2_TA1X1X8X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt4x64x16_wt4x64x1_ws1x1_wr1x1_ta1x1x1x1_1x16x1x4_tb1x1x16x1_1x16x1x4_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT4X64X16_WT4X64X1_WS1X1_WR1X1_TA1X1X1X1_1X16X1X4_TB1X1X16X1_1X16X1X4_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x8x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x128x16_wt8x32x1_ws2x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x8x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X16_WT8X32X1_WS2X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X8X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x128x8_wt8x32x1_ws2x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x4x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X128X8_WT8X32X1_WS2X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X4X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x16x16_wt64x4x1_ws1x1_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x1x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X16X16_WT64X4X1_WS1X1_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X1X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x16x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x256x16_wt16x64x1_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x16x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X16_WT16X64X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X16X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x256x8_wt16x64x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x8x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X256X8_WT16X64X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X8X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x2x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x32x16_wt32x8x1_ws1x2_wr1x1_ta1x1x4x1_1x16x1x16_tb1x1x2x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X16_WT32X8X1_WS1X2_WR1X1_TA1X1X4X1_1X16X1X16_TB1X1X2X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x32x8_wt32x8x1_ws1x2_wr1x1_ta1x1x2x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X32X8_WT32X8X1_WS1X2_WR1X1_TA1X1X2X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x64x16_wt16x16x1_ws1x1_wr2x2_ta1x1x4x1_1x16x1x16_tb1x1x4x1_1x16x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X16_WT16X16X1_WS1X1_WR2X2_TA1X1X4X1_1X16X1X16_TB1X1X4X1_1X16X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx4_ex1_bt64x64x8_wt16x16x1_ws1x1_wr2x2_ta1x1x2x1_1x8x1x32_tb1x1x2x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX4_EX1_BT64X64X8_WT16X16X1_WS1X1_WR2X2_TA1X1X2X1_1X8X1X32_TB1X1X2X1_1X8X1X32_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx8_ex1_bt16x32x8_wt8x32x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx8_ex1_bt16x32x8_wt8x32x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x16_tb1x1x2x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT16X32X8_WT8X32X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X16_TB1X1X2X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx8_ex1_bt32x16x8_wt32x8x1_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X16X8_WT32X8X1_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X16X8_WT32X8X1_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx8_ex1_bt32x16x8_wt32x8x1_ws1x1_wr1x1_ta1x1x2x1_1x8x1x16_tb1x1x1x1_1x8x1x16_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X16X8_WT32X8X1_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X16X8_WT32X8X1_WS1X1_WR1X1_TA1X1X2X1_1X8X1X16_TB1X1X1X1_1X8X1X16_GKGS_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx8_ex1_bt32x32x8_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_SIZE } },
    { "igemm_wrw_gtcx_nchw_fp32_bx8_ex1_bt32x32x8_wt16x16x1_ws1x1_wr1x1_ta1x1x1x1_1x8x1x32_tb1x1x1x1_1x8x1x32_gkgs.s", { MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS, MIOPEN_KERNEL_IGEMM_WRW_GTCX_NCHW_FP32_BX8_EX1_BT32X32X8_WT16X16X1_WS1X1_WR1X1_TA1X1X1X1_1X8X1X32_TB1X1X1X1_1X8X1X32_GKGS_SIZE } },
    { "wrw_reduction_hip.cpp", { MIOPEN_KERNEL_WRW_REDUCTION_HIP, MIOPEN_KERNEL_WRW_REDUCTION_HIP_SIZE } },
    { "fp8_naive_conv.cpp", { MIOPEN_KERNEL_FP8_NAIVE_CONV, MIOPEN_KERNEL_FP8_NAIVE_CONV_SIZE } },
    { "naive_conv.cpp", { MIOPEN_KERNEL_NAIVE_CONV, MIOPEN_KERNEL_NAIVE_CONV_SIZE } },
    { "naive_conv_gcn.s", { MIOPEN_KERNEL_NAIVE_CONV_GCN, MIOPEN_KERNEL_NAIVE_CONV_GCN_SIZE } },
    { "batched_transpose.cpp", { MIOPEN_KERNEL_BATCHED_TRANSPOSE, MIOPEN_KERNEL_BATCHED_TRANSPOSE_SIZE } },
    { "general_tensor_reorder_16x256_byte.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_BYTE, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_BYTE_SIZE } },
    { "general_tensor_reorder_16x256_dword.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_DWORD, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_DWORD_SIZE } },
    { "general_tensor_reorder_16x256_dwordx2.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_DWORDX2, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_DWORDX2_SIZE } },
    { "general_tensor_reorder_16x256_half.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_HALF, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_16X256_HALF_SIZE } },
    { "general_tensor_reorder_1x256_byte.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_BYTE, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_BYTE_SIZE } },
    { "general_tensor_reorder_1x256_dword.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_DWORD, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_DWORD_SIZE } },
    { "general_tensor_reorder_1x256_dwordx2.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_DWORDX2, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_DWORDX2_SIZE } },
    { "general_tensor_reorder_1x256_half.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_HALF, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_1X256_HALF_SIZE } },
    { "general_tensor_reorder_2x256_byte.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_BYTE, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_BYTE_SIZE } },
    { "general_tensor_reorder_2x256_dword.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_DWORD, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_DWORD_SIZE } },
    { "general_tensor_reorder_2x256_dwordx2.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_DWORDX2, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_DWORDX2_SIZE } },
    { "general_tensor_reorder_2x256_half.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_HALF, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_2X256_HALF_SIZE } },
    { "general_tensor_reorder_4x256_byte.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_BYTE, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_BYTE_SIZE } },
    { "general_tensor_reorder_4x256_dword.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_DWORD, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_DWORD_SIZE } },
    { "general_tensor_reorder_4x256_dwordx2.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_DWORDX2, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_DWORDX2_SIZE } },
    { "general_tensor_reorder_4x256_half.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_HALF, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_4X256_HALF_SIZE } },
    { "general_tensor_reorder_8x256_byte.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_BYTE, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_BYTE_SIZE } },
    { "general_tensor_reorder_8x256_dword.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_DWORD, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_DWORD_SIZE } },
    { "general_tensor_reorder_8x256_dwordx2.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_DWORDX2, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_DWORDX2_SIZE } },
    { "general_tensor_reorder_8x256_half.cpp", { MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_HALF, MIOPEN_KERNEL_GENERAL_TENSOR_REORDER_8X256_HALF_SIZE } },
    { "MIOpenAdam.cpp", { MIOPEN_KERNEL_MIOPENADAM, MIOPEN_KERNEL_MIOPENADAM_SIZE } },
    { "MIOpenCat.cpp", { MIOPEN_KERNEL_MIOPENCAT, MIOPEN_KERNEL_MIOPENCAT_SIZE } },
    { "MIOpenCheckNumerics.cpp", { MIOPEN_KERNEL_MIOPENCHECKNUMERICS, MIOPEN_KERNEL_MIOPENCHECKNUMERICS_SIZE } },
    { "MIOpenBatchNormActivBwdPerAct.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMACTIVBWDPERACT, MIOPEN_KERNEL_MIOPENBATCHNORMACTIVBWDPERACT_SIZE } },
    { "MIOpenBatchNormActivBwdSpatial.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMACTIVBWDSPATIAL, MIOPEN_KERNEL_MIOPENBATCHNORMACTIVBWDSPATIAL_SIZE } },
    { "MIOpenBatchNormActivFwdTrainPerAct.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMACTIVFWDTRAINPERACT, MIOPEN_KERNEL_MIOPENBATCHNORMACTIVFWDTRAINPERACT_SIZE } },
    { "MIOpenBatchNormActivFwdTrainSpatial.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMACTIVFWDTRAINSPATIAL, MIOPEN_KERNEL_MIOPENBATCHNORMACTIVFWDTRAINSPATIAL_SIZE } },
    { "MIOpenBatchNormFwdTrainSpatial.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMFWDTRAINSPATIAL, MIOPEN_KERNEL_MIOPENBATCHNORMFWDTRAINSPATIAL_SIZE } },
    { "MIOpenBatchNormFwdTrainPerAct.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMFWDTRAINPERACT, MIOPEN_KERNEL_MIOPENBATCHNORMFWDTRAINPERACT_SIZE } },
    { "MIOpenBatchNormFwdInferSpatial.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMFWDINFERSPATIAL, MIOPEN_KERNEL_MIOPENBATCHNORMFWDINFERSPATIAL_SIZE } },
    { "MIOpenBatchNormFwdInferPerAct.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMFWDINFERPERACT, MIOPEN_KERNEL_MIOPENBATCHNORMFWDINFERPERACT_SIZE } },
    { "MIOpenBatchNormBwdSpatial.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMBWDSPATIAL, MIOPEN_KERNEL_MIOPENBATCHNORMBWDSPATIAL_SIZE } },
    { "MIOpenBatchNormBwdPerAct.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMBWDPERACT, MIOPEN_KERNEL_MIOPENBATCHNORMBWDPERACT_SIZE } },
    { "MIOpenConvDirUni.cl", { MIOPEN_KERNEL_MIOPENCONVDIRUNI, MIOPEN_KERNEL_MIOPENCONVDIRUNI_SIZE } },
    { "MIOpenConvDirBatchNormActiv.cl", { MIOPEN_KERNEL_MIOPENCONVDIRBATCHNORMACTIV, MIOPEN_KERNEL_MIOPENCONVDIRBATCHNORMACTIV_SIZE } },
    { "MIOpenConvDirGenFwd.cl", { MIOPEN_KERNEL_MIOPENCONVDIRGENFWD, MIOPEN_KERNEL_MIOPENCONVDIRGENFWD_SIZE } },
    { "MIOpenGLU.cpp", { MIOPEN_KERNEL_MIOPENGLU, MIOPEN_KERNEL_MIOPENGLU_SIZE } },
    { "MIOpenGroupNorm.cpp", { MIOPEN_KERNEL_MIOPENGROUPNORM, MIOPEN_KERNEL_MIOPENGROUPNORM_SIZE } },
    { "MIOpenGetitem.cpp", { MIOPEN_KERNEL_MIOPENGETITEM, MIOPEN_KERNEL_MIOPENGETITEM_SIZE } },
    { "MIOpenKthvalue.cpp", { MIOPEN_KERNEL_MIOPENKTHVALUE, MIOPEN_KERNEL_MIOPENKTHVALUE_SIZE } },
    { "MIOpenLayerNorm.cpp", { MIOPEN_KERNEL_MIOPENLAYERNORM, MIOPEN_KERNEL_MIOPENLAYERNORM_SIZE } },
    { "MIOpenLRNBwd.cl", { MIOPEN_KERNEL_MIOPENLRNBWD, MIOPEN_KERNEL_MIOPENLRNBWD_SIZE } },
    { "MIOpenLRNFwd.cl", { MIOPEN_KERNEL_MIOPENLRNFWD, MIOPEN_KERNEL_MIOPENLRNFWD_SIZE } },
    { "MIOpenMultiMarginLoss.cpp", { MIOPEN_KERNEL_MIOPENMULTIMARGINLOSS, MIOPEN_KERNEL_MIOPENMULTIMARGINLOSS_SIZE } },
    { "MIOpenNeuron.cl", { MIOPEN_KERNEL_MIOPENNEURON, MIOPEN_KERNEL_MIOPENNEURON_SIZE } },
    { "MIOpenPReLU.cpp", { MIOPEN_KERNEL_MIOPENPRELU, MIOPEN_KERNEL_MIOPENPRELU_SIZE } },
    { "MIOpenPooling.cl", { MIOPEN_KERNEL_MIOPENPOOLING, MIOPEN_KERNEL_MIOPENPOOLING_SIZE } },
    { "MIOpenPoolingBwd.cl", { MIOPEN_KERNEL_MIOPENPOOLINGBWD, MIOPEN_KERNEL_MIOPENPOOLINGBWD_SIZE } },
    { "MIOpenPoolingBwdND.cl", { MIOPEN_KERNEL_MIOPENPOOLINGBWDND, MIOPEN_KERNEL_MIOPENPOOLINGBWDND_SIZE } },
    { "MIOpenPoolingForwardNaive.cl", { MIOPEN_KERNEL_MIOPENPOOLINGFORWARDNAIVE, MIOPEN_KERNEL_MIOPENPOOLINGFORWARDNAIVE_SIZE } },
    { "MIOpenPoolingND.cl", { MIOPEN_KERNEL_MIOPENPOOLINGND, MIOPEN_KERNEL_MIOPENPOOLINGND_SIZE } },
    { "MIOpenConv1x1S.cl", { MIOPEN_KERNEL_MIOPENCONV1X1S, MIOPEN_KERNEL_MIOPENCONV1X1S_SIZE } },
    { "MIOpenConv1x1J1.cl", { MIOPEN_KERNEL_MIOPENCONV1X1J1, MIOPEN_KERNEL_MIOPENCONV1X1J1_SIZE } },
    { "MIOpenConv1x1J1_stride.cl", { MIOPEN_KERNEL_MIOPENCONV1X1J1_STRIDE, MIOPEN_KERNEL_MIOPENCONV1X1J1_STRIDE_SIZE } },
    { "MIOpenReduceCalculation.cpp", { MIOPEN_KERNEL_MIOPENREDUCECALCULATION, MIOPEN_KERNEL_MIOPENREDUCECALCULATION_SIZE } },
    { "MIOpenReduceExtreme.cpp", { MIOPEN_KERNEL_MIOPENREDUCEEXTREME, MIOPEN_KERNEL_MIOPENREDUCEEXTREME_SIZE } },
    { "MIOpenReduceSum.cpp", { MIOPEN_KERNEL_MIOPENREDUCESUM, MIOPEN_KERNEL_MIOPENREDUCESUM_SIZE } },
    { "MIOpenRoPE.cpp", { MIOPEN_KERNEL_MIOPENROPE, MIOPEN_KERNEL_MIOPENROPE_SIZE } },
    { "MIOpenSoftMarginLoss.cpp", { MIOPEN_KERNEL_MIOPENSOFTMARGINLOSS, MIOPEN_KERNEL_MIOPENSOFTMARGINLOSS_SIZE } },
    { "MIOpenSoftmax.cl", { MIOPEN_KERNEL_MIOPENSOFTMAX, MIOPEN_KERNEL_MIOPENSOFTMAX_SIZE } },
    { "MIOpenSoftmaxAttn.cpp", { MIOPEN_KERNEL_MIOPENSOFTMAXATTN, MIOPEN_KERNEL_MIOPENSOFTMAXATTN_SIZE } },
    { "MIOpenUtilKernels3.cl", { MIOPEN_KERNEL_MIOPENUTILKERNELS3, MIOPEN_KERNEL_MIOPENUTILKERNELS3_SIZE } },
    { "MIOpenUtilKernels4.cl", { MIOPEN_KERNEL_MIOPENUTILKERNELS4, MIOPEN_KERNEL_MIOPENUTILKERNELS4_SIZE } },
    { "MIOpenUtilKernels5.cl", { MIOPEN_KERNEL_MIOPENUTILKERNELS5, MIOPEN_KERNEL_MIOPENUTILKERNELS5_SIZE } },
    { "MIOpenVecAdd.cpp", { MIOPEN_KERNEL_MIOPENVECADD, MIOPEN_KERNEL_MIOPENVECADD_SIZE } },
    { "MIOpenVecAddOCL.cl", { MIOPEN_KERNEL_MIOPENVECADDOCL, MIOPEN_KERNEL_MIOPENVECADDOCL_SIZE } },
    { "MIOpenIm2d2Col.cl", { MIOPEN_KERNEL_MIOPENIM2D2COL, MIOPEN_KERNEL_MIOPENIM2D2COL_SIZE } },
    { "MIOpenIm3d2Col.cl", { MIOPEN_KERNEL_MIOPENIM3D2COL, MIOPEN_KERNEL_MIOPENIM3D2COL_SIZE } },
    { "MIOpenCol2Im2d.cl", { MIOPEN_KERNEL_MIOPENCOL2IM2D, MIOPEN_KERNEL_MIOPENCOL2IM2D_SIZE } },
    { "MIOpenCol2Im3d.cl", { MIOPEN_KERNEL_MIOPENCOL2IM3D, MIOPEN_KERNEL_MIOPENCOL2IM3D_SIZE } },
    { "MIOpenConvBwdWrWS2.cl", { MIOPEN_KERNEL_MIOPENCONVBWDWRWS2, MIOPEN_KERNEL_MIOPENCONVBWDWRWS2_SIZE } },
    { "MIOpenGroupConvBwdWrWS2.cl", { MIOPEN_KERNEL_MIOPENGROUPCONVBWDWRWS2, MIOPEN_KERNEL_MIOPENGROUPCONVBWDWRWS2_SIZE } },
    { "MIOpenConvBwdWrW_LxG_P53.cl", { MIOPEN_KERNEL_MIOPENCONVBWDWRW_LXG_P53, MIOPEN_KERNEL_MIOPENCONVBWDWRW_LXG_P53_SIZE } },
    { "MIOpenGroupConvBwdWrW_LxG_P53.cl", { MIOPEN_KERNEL_MIOPENGROUPCONVBWDWRW_LXG_P53, MIOPEN_KERNEL_MIOPENGROUPCONVBWDWRW_LXG_P53_SIZE } },
    { "MIOpenConvBwdWrW_LxG_5x5.cl", { MIOPEN_KERNEL_MIOPENCONVBWDWRW_LXG_5X5, MIOPEN_KERNEL_MIOPENCONVBWDWRW_LXG_5X5_SIZE } },
    { "MIOpenConvBwdWrW1x1_PAD_read4.cl", { MIOPEN_KERNEL_MIOPENCONVBWDWRW1X1_PAD_READ4, MIOPEN_KERNEL_MIOPENCONVBWDWRW1X1_PAD_READ4_SIZE } },
    { "MIOpenConvFwd_LxL_11.cl", { MIOPEN_KERNEL_MIOPENCONVFWD_LXL_11, MIOPEN_KERNEL_MIOPENCONVFWD_LXL_11_SIZE } },
    { "MIOpenConvFFT.cl", { MIOPEN_KERNEL_MIOPENCONVFFT, MIOPEN_KERNEL_MIOPENCONVFFT_SIZE } },
    { "MIOpenRNNHiddenStateUpdate.cl", { MIOPEN_KERNEL_MIOPENRNNHIDDENSTATEUPDATE, MIOPEN_KERNEL_MIOPENRNNHIDDENSTATEUPDATE_SIZE } },
    { "bugzilla_34765_detect.s", { MIOPEN_KERNEL_BUGZILLA_34765_DETECT, MIOPEN_KERNEL_BUGZILLA_34765_DETECT_SIZE } },
    { "dummy_kernel.s", { MIOPEN_KERNEL_DUMMY_KERNEL, MIOPEN_KERNEL_DUMMY_KERNEL_SIZE } },
    { "conv3x3.s", { MIOPEN_KERNEL_CONV3X3, MIOPEN_KERNEL_CONV3X3_SIZE } },
    { "conv1x1u.s", { MIOPEN_KERNEL_CONV1X1U, MIOPEN_KERNEL_CONV1X1U_SIZE } },
    { "conv1x1u_stride2.s", { MIOPEN_KERNEL_CONV1X1U_STRIDE2, MIOPEN_KERNEL_CONV1X1U_STRIDE2_SIZE } },
    { "conv1x1u_bias_activ.s", { MIOPEN_KERNEL_CONV1X1U_BIAS_ACTIV, MIOPEN_KERNEL_CONV1X1U_BIAS_ACTIV_SIZE } },
    { "conv3x3wrw.s", { MIOPEN_KERNEL_CONV3X3WRW, MIOPEN_KERNEL_CONV3X3WRW_SIZE } },
    { "conv1x1wrw.s", { MIOPEN_KERNEL_CONV1X1WRW, MIOPEN_KERNEL_CONV1X1WRW_SIZE } },
    { "conv5x10u2v2f1.s", { MIOPEN_KERNEL_CONV5X10U2V2F1, MIOPEN_KERNEL_CONV5X10U2V2F1_SIZE } },
    { "conv5x10u2v2b1.s", { MIOPEN_KERNEL_CONV5X10U2V2B1, MIOPEN_KERNEL_CONV5X10U2V2B1_SIZE } },
    { "conv7x7c3h224w224k64u2v2p3q3f1.s", { MIOPEN_KERNEL_CONV7X7C3H224W224K64U2V2P3Q3F1, MIOPEN_KERNEL_CONV7X7C3H224W224K64U2V2P3Q3F1_SIZE } },
    { "xform_out.s", { MIOPEN_KERNEL_XFORM_OUT, MIOPEN_KERNEL_XFORM_OUT_SIZE } },
    { "gcnAsmBNBwdTrainSpatial.s", { MIOPEN_KERNEL_GCNASMBNBWDTRAINSPATIAL, MIOPEN_KERNEL_GCNASMBNBWDTRAINSPATIAL_SIZE } },
    { "MIOpenTensorKernels.cl", { MIOPEN_KERNEL_MIOPENTENSORKERNELS, MIOPEN_KERNEL_MIOPENTENSORKERNELS_SIZE } },
    { "MIOpenTensorKernelsHip.cpp", { MIOPEN_KERNEL_MIOPENTENSORKERNELSHIP, MIOPEN_KERNEL_MIOPENTENSORKERNELSHIP_SIZE } },
    { "MIOpenSubTensorOpWithScalarKernel.cl", { MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHSCALARKERNEL, MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHSCALARKERNEL_SIZE } },
    { "MIOpenSubTensorOpWithSubTensorKernel.cl", { MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHSUBTENSORKERNEL, MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHSUBTENSORKERNEL_SIZE } },
    { "MIOpenSubTensorOpWithCastTensorKernel.cl", { MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHCASTTENSORKERNEL, MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHCASTTENSORKERNEL_SIZE } },
    { "MIOpenSubTensorOpWithTransformKernel.cl", { MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHTRANSFORMKERNEL, MIOPEN_KERNEL_MIOPENSUBTENSOROPWITHTRANSFORMKERNEL_SIZE } },
    { "Conv_Winograd_v13_3_12_fp16dot_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE1_SIZE } },
    { "Conv_Winograd_v13_3_12_fp16dot_stride2_dec.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE2_DEC, MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE2_DEC_SIZE } },
    { "Conv_Winograd_v13_3_12_fp16dot_stride2_dil.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE2_DIL, MIOPEN_KERNEL_CONV_WINOGRAD_V13_3_12_FP16DOT_STRIDE2_DIL_SIZE } },
    { "Conv_Winograd_v14_3_3_fp16dot_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE1_SIZE } },
    { "Conv_Winograd_v14_3_3_fp16dot_stride2_dec.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE2_DEC, MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE2_DEC_SIZE } },
    { "Conv_Winograd_v14_3_3_fp16dot_stride2_dil.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE2_DIL, MIOPEN_KERNEL_CONV_WINOGRAD_V14_3_3_FP16DOT_STRIDE2_DIL_SIZE } },
    { "Conv_Winograd_v16_5_0_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V16_5_0_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V16_5_0_STRIDE1_SIZE } },
    { "conv_3x3_wheel_alpha_v9_0_15_stride_2_dil.s", { MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_STRIDE_2_DIL, MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_STRIDE_2_DIL_SIZE } },
    { "conv_3x3_wheel_alpha_v9_0_15_stride_2_dec.s", { MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_STRIDE_2_DEC, MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_STRIDE_2_DEC_SIZE } },
    { "conv_3x3_wheel_alpha_v9_0_15.s", { MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15, MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_0_15_SIZE } },
    { "conv_3x3_wheel_alpha_v7_0_3b.s", { MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V7_0_3B, MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V7_0_3B_SIZE } },
    { "conv_3x3_wheel_alpha_v3_0b.s", { MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V3_0B, MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V3_0B_SIZE } },
    { "conv_3x3_wheel_alpha_v9_2_7.s", { MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_2_7, MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_2_7_SIZE } },
    { "conv_3x3_wheel_alpha_v9_2_7_stride_2_dec.s", { MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_2_7_STRIDE_2_DEC, MIOPEN_KERNEL_CONV_3X3_WHEEL_ALPHA_V9_2_7_STRIDE_2_DEC_SIZE } },
    { "Conv_Winograd_v21_1_3_fp16_dot2_f2x3_dilation2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_DILATION2, MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_DILATION2_SIZE } },
    { "Conv_Winograd_v21_1_3_fp16_dot2_f2x3_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_STRIDE1_SIZE } },
    { "Conv_Winograd_v21_1_3_fp16_dot2_f2x3_stride2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_STRIDE2, MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F2X3_STRIDE2_SIZE } },
    { "Conv_Winograd_v21_1_3_fp16_dot2_f3x2_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F3X2_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP16_DOT2_F3X2_STRIDE1_SIZE } },
    { "Conv_Winograd_v21_1_3_fp32_f2x3_dilation2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_DILATION2, MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_DILATION2_SIZE } },
    { "Conv_Winograd_v21_1_3_fp32_f2x3_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_STRIDE1_SIZE } },
    { "Conv_Winograd_v21_1_3_fp32_f2x3_stride2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_STRIDE2, MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F2X3_STRIDE2_SIZE } },
    { "Conv_Winograd_v21_1_3_fp32_f3x2_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F3X2_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V21_1_3_FP32_F3X2_STRIDE1_SIZE } },
    { "Conv_Winograd_v30_3_1_fp16_dot2_f2x3_dilation2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_DILATION2, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_DILATION2_SIZE } },
    { "Conv_Winograd_v30_3_1_fp16_dot2_f2x3_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_STRIDE1_SIZE } },
    { "Conv_Winograd_v30_3_1_fp16_dot2_f2x3_stride2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_STRIDE2, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F2X3_STRIDE2_SIZE } },
    { "Conv_Winograd_v30_3_1_fp32_f2x3_dilation2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_DILATION2, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_DILATION2_SIZE } },
    { "Conv_Winograd_v30_3_1_fp32_f2x3_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_STRIDE1_SIZE } },
    { "Conv_Winograd_v30_3_1_fp32_f2x3_stride2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_STRIDE2, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F2X3_STRIDE2_SIZE } },
    { "Conv_Winograd_v30_3_1_fp16_dot2_f3x2_dilation2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_DILATION2, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_DILATION2_SIZE } },
    { "Conv_Winograd_v30_3_1_fp16_dot2_f3x2_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_STRIDE1_SIZE } },
    { "Conv_Winograd_v30_3_1_fp16_dot2_f3x2_stride2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_STRIDE2, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP16_DOT2_F3X2_STRIDE2_SIZE } },
    { "Conv_Winograd_v30_3_1_fp32_f3x2_dilation2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_DILATION2, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_DILATION2_SIZE } },
    { "Conv_Winograd_v30_3_1_fp32_f3x2_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_STRIDE1_SIZE } },
    { "Conv_Winograd_v30_3_1_fp32_f3x2_stride2.s", { MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_STRIDE2, MIOPEN_KERNEL_CONV_WINOGRAD_V30_3_1_FP32_F3X2_STRIDE2_SIZE } },
    { "MIOpenConvBwdBias.cl", { MIOPEN_KERNEL_MIOPENCONVBWDBIAS, MIOPEN_KERNEL_MIOPENCONVBWDBIAS_SIZE } },
    { "MIOpenBatchNormActivInfer.cl", { MIOPEN_KERNEL_MIOPENBATCHNORMACTIVINFER, MIOPEN_KERNEL_MIOPENBATCHNORMACTIVINFER_SIZE } },
    { "MIOpenBatchNormActivInferHIP.cpp", { MIOPEN_KERNEL_MIOPENBATCHNORMACTIVINFERHIP, MIOPEN_KERNEL_MIOPENBATCHNORMACTIVINFERHIP_SIZE } },
    { "MIOpenCTCLoss.cl", { MIOPEN_KERNEL_MIOPENCTCLOSS, MIOPEN_KERNEL_MIOPENCTCLOSS_SIZE } },
    { "MIOpenDropoutHIP.cpp", { MIOPEN_KERNEL_MIOPENDROPOUTHIP, MIOPEN_KERNEL_MIOPENDROPOUTHIP_SIZE } },
    { "Conv_Winograd_Fury_v2_4_1_fp16_fp16acc_f2x3_c16_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_FURY_V2_4_1_FP16_FP16ACC_F2X3_C16_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_FURY_V2_4_1_FP16_FP16ACC_F2X3_C16_STRIDE1_SIZE } },
    { "Conv_Winograd_Fury_v2_4_1_fp16_fp16acc_f2x3_c32_stride1.s", { MIOPEN_KERNEL_CONV_WINOGRAD_FURY_V2_4_1_FP16_FP16ACC_F2X3_C32_STRIDE1, MIOPEN_KERNEL_CONV_WINOGRAD_FURY_V2_4_1_FP16_FP16ACC_F2X3_C32_STRIDE1_SIZE } },
    { "xform_data.s", { MIOPEN_KERNEL_XFORM_DATA, MIOPEN_KERNEL_XFORM_DATA_SIZE } },
    { "xform_filter.s", { MIOPEN_KERNEL_XFORM_FILTER, MIOPEN_KERNEL_XFORM_FILTER_SIZE } },
    { "xform_bidirect_winograd_data.s", { MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_DATA, MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_DATA_SIZE } },
    { "xform_bidirect_winograd_filter.s", { MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_FILTER, MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_FILTER_SIZE } },
    { "xform_bidirect_winograd_out.s", { MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_OUT, MIOPEN_KERNEL_XFORM_BIDIRECT_WINOGRAD_OUT_SIZE } },
    { "UniversalTranspose.cl", { MIOPEN_KERNEL_UNIVERSALTRANSPOSE, MIOPEN_KERNEL_UNIVERSALTRANSPOSE_SIZE } }
#endif
    };
    return data;
}

std::string_view GetKernelSrc(const fs::path& name)
{
    // Use the base name of the string
    auto it = kernels().find(name.filename());
    if(it == kernels().end())
        MIOPEN_THROW("Failed to load kernel source: " + name.filename());

    return it->second;
}

} // namespace miopen
